/***************************************************************
 * Name:      dxtime.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#ifdef __BORLANDC__
#pragma hdrstop
#endif //__BORLANDC__

#include <wx/aboutdlg.h>
#include <wx/sysopt.h>
#include <wx/taskbar.h>
#include "config.h"
#include "dxtime.h"
#include "dxdefs.h"
#include "utils/settings.h"
#include "gui/dialogs/taskdialog.h"
#include "gui/dialogs/reportdialog.h"
#include "utils/dxicons.h"

dxtimeFrame* frame = NULL;
bool frameShown = true;

IMPLEMENT_APP(dxtimeApp)

bool dxtimeApp::OnInit()
{
    m_checker = new wxSingleInstanceChecker;
    if(m_checker->IsAnotherRunning())
    {
        wxLogWarning(_("dxTime already running"));
        delete m_checker; // OnExit() won't be called if we return false
        m_checker = NULL;
        return false;
    }
    wxInitAllImageHandlers();
    settings.load();
    makeAllIcons("default");
#if defined (__WXMAC__) || defined (__WXOSX__)
    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"),1);
#endif
    wxLocale::AddCatalogLookupPathPrefix(LOCALEDIR);
    m_locale = new wxLocale();
    m_locale->Init(wxLANGUAGE_DEFAULT);
    m_locale->AddCatalog("dxtime");
    m_locale->AddCatalog("wxstd");

    frame = new dxtimeFrame(0L, "dxTime");
    frame->SetIcon(ICO_ICON); // To Set App Icon
    frame->Show();
    return true;
}

int dxtimeApp::OnExit()
{
    if(m_checker)
        delete m_checker;
    return 0;
}

BEGIN_EVENT_TABLE(dxTaskBarIcon, wxTaskBarIcon)
    EVT_TASKBAR_LEFT_DCLICK(dxTaskBarIcon::OnLeftButtonDClick)
    EVT_MENU(ID_TASK_RESTORE, dxTaskBarIcon::OnRestore)
    EVT_MENU(wxID_EXIT, dxTaskBarIcon::OnQuit)
    EVT_MENU(ID_SUBTASK, dxTaskBarIcon::OnSubtask)
    EVT_MENU(ID_RECORDPAUSE, dxTaskBarIcon::OnRecordPause)
END_EVENT_TABLE()

void dxTaskBarIcon::OnLeftButtonDClick(wxTaskBarIconEvent&)
{
    if(frameShown)
        frame->Show(false);
    else
    {
        frame->Show(true);
        frame->Iconize(false);
    }
    frameShown = !frameShown;
}

wxMenu *dxTaskBarIcon::CreatePopupMenu()
{
    wxMenu *menu = new wxMenu;
    if(frameShown)
        menu->Append(ID_TASK_RESTORE, _("Hide"));
    else
        menu->Append(ID_TASK_RESTORE, _("Restore"));
    menu->AppendSeparator();
    menu->Append(ID_SUBTASK, _("New task"));
    menu->AppendSeparator();
    menu->Append(ID_RECORDPAUSE, frame->isRecording()?_("Pause recording"):wxString::Format(_("Start recording '%s'"), frame->currentTask().c_str()));
    menu->AppendSeparator();
    menu->Append(wxID_EXIT);
    return menu;
}

void dxTaskBarIcon::OnRestore(wxCommandEvent& /*event*/)
{
    if(frameShown)
        frame->Show(false);
    else
    {
        frame->Show(true);
        frame->Iconize(false);
    }
    frameShown = !frameShown;
}

void dxTaskBarIcon::OnQuit(wxCommandEvent& event)
{
    wxPostEvent(frame, event);
}

void dxTaskBarIcon::OnSubtask(wxCommandEvent& event)
{
    wxPostEvent(frame, event);
}

void dxTaskBarIcon::OnRecordPause(wxCommandEvent &event)
{
    wxPostEvent(frame, event);
}

BEGIN_EVENT_TABLE(dxtimeFrame, wxFrame)
    EVT_CLOSE(dxtimeFrame::OnClose)
    EVT_MENU(wxID_EXIT, dxtimeFrame::OnQuit)
    EVT_MENU(wxID_ABOUT, dxtimeFrame::OnAbout)
    EVT_TREE_SEL_CHANGED(ID_TASKSTREE, dxtimeFrame::OnTasksChanged)
    EVT_TREE_ITEM_RIGHT_CLICK(ID_TASKSTREE, dxtimeFrame::OnTasksRightClick)
    EVT_COMMAND(wxID_ANY, RECORD_STARTED, dxtimeFrame::OnRecordStarted)
    EVT_COMMAND(wxID_ANY, RECORD_PAUSED, dxtimeFrame::OnRecordPaused)
    EVT_COMMAND(wxID_ANY, RECORD_TIMER, dxtimeFrame::OnRecordTimer)
    EVT_MENU(ID_SUBTASK, dxtimeFrame::OnSubtask)
    EVT_MENU(ID_EDITTASK, dxtimeFrame::OnEditTask)
    EVT_MENU(ID_DELETETASK, dxtimeFrame::OnDeleteTask)
    EVT_MENU(ID_RECORDPAUSE, dxtimeFrame::OnRecordPause)
    EVT_MENU(ID_CSV, dxtimeFrame::OnReportCsv)
    EVT_MENU(ID_HTML, dxtimeFrame::OnReportHtml)
    EVT_MENU(ID_TASKCSV, dxtimeFrame::OnTaskCsv)
    EVT_MENU(ID_TASKHTML, dxtimeFrame::OnTaskHtml)
END_EVENT_TABLE()

dxtimeFrame::dxtimeFrame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title, wxDefaultPosition, wxSize(800,600))
{
#if wxUSE_MENUS
    // create a menu bar
    wxMenuBar *mbar = new wxMenuBar();
    wxMenu *fileMenu = new wxMenu();
#if (defined (__WXMAC__) || defined (__WXOSX__))
    fileMenu->Append(wxID_ABOUT);
#endif
    fileMenu->Append(ID_SUBTASK, _("New task\tCtrl-N"));
    m_editTask = fileMenu->Append(ID_EDITTASK, _("Edit task"));
    m_editTask->Enable(false);
    m_deleteTask = fileMenu->Append(ID_DELETETASK, _("Delete task"));
    m_deleteTask->Enable(false);
    fileMenu->AppendSeparator();
    fileMenu->Append(wxID_EXIT);
    mbar->Append(fileMenu, _("&Tasks"));

    wxMenu *reportMenu = new wxMenu();
    reportMenu->Append(ID_CSV, "CSV");
    reportMenu->Append(ID_HTML, "HTML");
    mbar->Append(reportMenu, _("&Reports"));

#if !(defined (__WXMAC__) || defined (__WXOSX__))
    wxMenu *helpMenu = new wxMenu();
    helpMenu->Append(wxID_ABOUT);
    mbar->Append(helpMenu, _("&Help"));
#endif

    SetMenuBar(mbar);
#endif // wxUSE_MENUS

#if defined(__WXCOCOA__)
    m_dockIcon = new dxTaskBarIcon(wxTaskBarIcon::DOCK);
#else
    m_taskBarIcon = new dxTaskBarIcon();
    m_taskBarIcon->SetIcon(ICO_TRAY, "dxTime");
#endif

    loadDatabase();

    m_tasks = new Tree(this, ID_TASKSTREE);
    m_detail = new Detail(this);
    m_manager.AddPane(m_tasks, wxAuiPaneInfo().
                      Name("Navigation").Caption("Navigation").
                      BestSize(wxSize(200, 100)).MinSize(wxSize(100, 100)).
                      CaptionVisible(false).CloseButton(false).
                      Left());
    m_manager.AddPane(m_detail, wxAuiPaneInfo().
                      Name("Detail").Caption("Detail").
                      CenterPane().PaneBorder(false));
    m_manager.SetManagedWindow(this);
    m_manager.LoadPerspective(settings.auiperspective());
    m_manager.SetFlags(wxAUI_MGR_DEFAULT | wxAUI_MGR_TRANSPARENT_DRAG | wxAUI_MGR_ALLOW_ACTIVE_PANE);
    m_manager.Update();

    SetSize(settings.x(), settings.y(), settings.w(), settings.h());
    if(settings.maximized())
        Maximize();
    
    m_tasks->updateData();
    m_detail->updateData(-1);
}

dxtimeFrame::~dxtimeFrame()
{
    settings.setX(GetPosition().x);
    settings.setY(GetPosition().y);
    settings.setW(GetSize().x);
    settings.setH(GetSize().y);
    settings.setMaximized(IsMaximized());
    settings.setAuiperspective(m_manager.SavePerspective());
    settings.save();
    m_model->shutdownModel();
    m_manager.UnInit();
    delete m_taskBarIcon;
}

wxString dxtimeFrame::currentTask() const
{
    int id = -1;
    if(m_tasks->GetFocusedItem().IsOk())
    {
        id = dynamic_cast<IdItemData*>(m_tasks->GetItemData(m_tasks->GetFocusedItem()))->id();
    }
    return m_model->getTask(id).name();
}

bool dxtimeFrame::isRecording() const
{
    return m_detail->isRecording();
}

void dxtimeFrame::loadDatabase()
{
    m_model = new DbModel(this);
    m_model->initModel();
    if(m_model->openDatabase())
    {
        m_model->fillData();
    }
    else
    {
        wxLogError(_("Database couldn't open"));
    }
}

void dxtimeFrame::OnClose(wxCloseEvent& WXUNUSED(event))
{
    Show(false);
    frameShown = !frameShown;
}

void dxtimeFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
{
    m_detail->stopRecord();
    Destroy();
}

void dxtimeFrame::OnAbout(wxCommandEvent& WXUNUSED(event))
{
    wxString description = wxString() << wxVERSION_STRING << "\n"
                            << m_model->getVersion() << "\n"
                            << _("Uses http://www.famfamfam.com/lab/icons/");
    wxAboutDialogInfo info;
    info.SetIcon(ICO_ABOUT);
    info.SetName(PACKAGE);
    info.SetVersion(VERSION);
    info.SetDescription(description);
    info.SetCopyright("(c) 2015 ~");
    info.SetWebSite("http://dxtime.dxsolutions.org");
    info.AddDeveloper("David Vachulka <arch_dvx@users.sourceforge.net>");
    info.SetLicence(_(
            "This program is free software; you can redistribute it and/or modify it under the terms of\n"
            "the GNU General Public License as published by the Free Software Foundation;\n"
            "either version 3 of the License, or (at your option) any later version.\n\n"

            "This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;\n"
            "without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
            "See the GNU General Public License for more details.\n\n"

            "You should have received a copy of the GNU General Public License along with this program;\n"
            "if not, write to the Free Software Foundation, Inc., 51 Franklin Street,\n"
            "Fifth Floor, Boston, MA 02110-1301, USA"));
    wxAboutBox(info);
}

void dxtimeFrame::OnTasksChanged(wxTreeEvent& event)
{
    wxTreeItemId item = event.GetItem();
    if(!item) return;
    IdItemData *data = dynamic_cast<IdItemData*>(m_tasks->GetItemData(item));
    if(!data) return;
    m_detail->stopRecord();
    m_detail->updateData(data->id());
    m_taskBarIcon->SetIcon(ICO_TRAY, "dxTime");
    if(data->id() == -1)
    {
        m_editTask->Enable(false);
        m_deleteTask->Enable(false);
    }
    else
    {
        m_editTask->Enable(true);
        m_deleteTask->Enable(true);
    }
}

void dxtimeFrame::OnTasksRightClick(wxTreeEvent& event)
{
    wxTreeItemId item = event.GetItem();
    if(!item) return;
    IdItemData *data = dynamic_cast<IdItemData*>(m_tasks->GetItemData(item));
    if(!data) return;
    m_tasks->SelectItem(item);
    wxMenu *popup = new wxMenu();
    popup->Append(ID_SUBTASK, _("New task"));
    if(data->id() != -1)
    {
        popup->Append(ID_EDITTASK, _("Edit task"));
        popup->Append(ID_DELETETASK, _("Delete task"));
    }
    popup->AppendSeparator();
    wxMenu *popup1 = new wxMenu();
    popup1->Append(ID_TASKCSV, "CSV");
    popup1->Append(ID_TASKHTML, "HTML");
    popup->AppendSubMenu(popup1, _("Report"));
    PopupMenu(popup, event.GetPoint());
}

void dxtimeFrame::OnRecordStarted(wxCommandEvent& event)
{
    m_taskBarIcon->SetIcon(ICO_TPLAY, event.GetString());
}

void dxtimeFrame::OnRecordPaused(wxCommandEvent& /*event*/)
{
    m_taskBarIcon->SetIcon(ICO_TRAY, "dxTime");
}

void dxtimeFrame::OnRecordTimer(wxCommandEvent& event)
{
    m_taskBarIcon->SetIcon(ICO_TPLAY, event.GetString());
}

void dxtimeFrame::OnSubtask(wxCommandEvent& /*event*/)
{
    int id = -1;
    if(m_tasks->GetFocusedItem().IsOk())
    {
        id = dynamic_cast<IdItemData*>(m_tasks->GetItemData(m_tasks->GetFocusedItem()))->id();
    }
    TaskDialog dialog(this, id);
    if(dialog.ShowModal() == wxID_OK)
    {
        m_tasks->updateData();
        m_tasks->selectID(m_model->getLastId("task")-1);
        m_editTask->Enable(true);
        m_deleteTask->Enable(true);
    }
}

void dxtimeFrame::OnEditTask(wxCommandEvent& /*event*/)
{
    int id = -1;
    if(m_tasks->GetFocusedItem().IsOk())
    {
        id = dynamic_cast<IdItemData*>(m_tasks->GetItemData(m_tasks->GetFocusedItem()))->id();
    }
    if(id == -1) return;
    TaskDialog dialog(id, this);
    if(dialog.ShowModal() == wxID_OK)
    {
        m_tasks->updateData();
        m_tasks->selectID(id);
    }
}

void dxtimeFrame::OnDeleteTask(wxCommandEvent& /*event*/)
{
    int id = -1;
    if(m_tasks->GetFocusedItem().IsOk())
    {
        id = dynamic_cast<IdItemData*>(m_tasks->GetItemData(m_tasks->GetFocusedItem()))->id();
    }
    if(id == -1) return;
    wxMessageDialog dialog(this, wxString::Format(_("Really delete task '%s'\nand its subtasks?"), m_tasks->GetItemText(m_tasks->GetFocusedItem())), _("Question"), wxOK|wxCANCEL|wxICON_QUESTION);
    if(dialog.ShowModal() == wxID_OK)
    {
        m_model->deleteTask(id);
        m_tasks->updateData();
        m_tasks->selectID(-1);
    }
}

void dxtimeFrame::OnRecordPause(wxCommandEvent& /*event*/)
{
    m_detail->recordPause();
}

void dxtimeFrame::OnReportCsv(wxCommandEvent& /*event*/)
{
    ReportDialog dialog(this, true);
    dialog.ShowModal();
}

void dxtimeFrame::OnReportHtml(wxCommandEvent& /*event*/)
{
    ReportDialog dialog(this, false);
    dialog.ShowModal();
}

void dxtimeFrame::OnTaskCsv(wxCommandEvent& /*event*/)
{
    int id = -1;
    if(m_tasks->GetFocusedItem().IsOk())
    {
        id = dynamic_cast<IdItemData*>(m_tasks->GetItemData(m_tasks->GetFocusedItem()))->id();
    }
    ReportDialog dialog(this, id, true);
    dialog.ShowModal();
}

void dxtimeFrame::OnTaskHtml(wxCommandEvent& /*event*/)
{
    int id = -1;
    if(m_tasks->GetFocusedItem().IsOk())
    {
        id = dynamic_cast<IdItemData*>(m_tasks->GetItemData(m_tasks->GetFocusedItem()))->id();
    }
    ReportDialog dialog(this, id, false);
    dialog.ShowModal();
}

