/***************************************************************
 * Name:      dxtime.h
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#ifndef DXTIME_H
#define DXTIME_H

#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif
#include <wx/snglinst.h>
#include <wx/aui/aui.h>
#include "gui/navigation/tree.h"
#include "gui/pages/detail.h"
#include "model/dbmodel.h"

class dxtimeApp : public wxApp
{
public:
    virtual bool OnInit();
    virtual int OnExit();
protected:
    wxLocale *m_locale;
    wxSingleInstanceChecker *m_checker;
};

class dxTaskBarIcon: public wxTaskBarIcon
{
public:
#if defined(__WXCOCOA__)
    dxTaskBarIcon(wxTaskBarIconType iconType = DEFAULT_TYPE) : wxTaskBarIcon(iconType)
#else
    dxTaskBarIcon()
#endif
    {}

    void OnLeftButtonDClick(wxTaskBarIconEvent&);
    virtual wxMenu *CreatePopupMenu();
private:
    void OnRestore(wxCommandEvent& event);
    void OnQuit(wxCommandEvent& event);
    void OnSubtask(wxCommandEvent& event);
    void OnRecordPause(wxCommandEvent& event);
DECLARE_EVENT_TABLE()
};

class dxtimeFrame : public wxFrame
{
public:
    dxtimeFrame(wxFrame *frame, const wxString& title);
    ~dxtimeFrame();

    wxString currentTask() const;
    bool isRecording() const;
private:
    dxTaskBarIcon *m_taskBarIcon;
    wxAuiManager m_manager;
    Tree *m_tasks;
    Detail *m_detail;
    DbModel *m_model;
    wxMenuItem *m_editTask;
    wxMenuItem *m_deleteTask;

    void loadDatabase();
    void OnAbout(wxCommandEvent& event);
    void OnQuit(wxCommandEvent& event);
    void OnClose(wxCloseEvent& event);
    void OnTasksChanged(wxTreeEvent& event);
    void OnTasksRightClick(wxTreeEvent& event);
    void OnRecordStarted(wxCommandEvent& event);
    void OnRecordPaused(wxCommandEvent& event);
    void OnRecordTimer(wxCommandEvent& event);
    void OnSubtask(wxCommandEvent& event);
    void OnEditTask(wxCommandEvent& event);
    void OnDeleteTask(wxCommandEvent& event);
    void OnRecordPause(wxCommandEvent& event);
    void OnReportHtml(wxCommandEvent& event);
    void OnReportCsv(wxCommandEvent& event);
    void OnTaskHtml(wxCommandEvent& event);
    void OnTaskCsv(wxCommandEvent& event);
DECLARE_EVENT_TABLE()
};


#endif // DXTIME_H
