/***************************************************************
 * Name:      taskdialog.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#include "dxdefs.h"
#include "taskdialog.h"
#include "model/dbmodel.h"

IMPLEMENT_DYNAMIC_CLASS(TaskDialog, wxDialog)

BEGIN_EVENT_TABLE(TaskDialog, wxDialog)
    EVT_BUTTON(wxID_OK, TaskDialog::OnOk)
    EVT_BUTTON(wxID_CANCEL, TaskDialog::OnCancel)
END_EVENT_TABLE()

TaskDialog::TaskDialog(wxWindow *parent)
: wxDialog(parent, wxID_ANY, _("New task")), m_editing(false), m_taskid(-1)
{
    createControls();
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

TaskDialog::TaskDialog(wxWindow *parent, int parentid)
: wxDialog(parent, wxID_ANY, _("New task")), m_editing(false), m_taskid(-1)
{
    createControls();
    m_tasks->selectID(parentid);
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

TaskDialog::TaskDialog(int taskid, wxWindow *parent)
: wxDialog(parent, wxID_ANY, _("Edit task")), m_editing(true), m_taskid(taskid)
{
    createControls();
    fillControls();
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

void TaskDialog::createControls()
{
    m_mainSizer = new wxBoxSizer(wxVERTICAL);
    
    wxFlexGridSizer *gridSizer = new wxFlexGridSizer(2, 5, 5);

    gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Task:")), wxSizerFlags().Align(wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL).Border(wxLEFT | wxUP, 5));
    m_nameCtrl = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_nameCtrl, wxSizerFlags().Expand().Align(wxALIGN_CENTER_VERTICAL).Border(wxUP, 5));

    gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Description:")), wxSizerFlags().Align(wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL).Border(wxLEFT | wxUP, 5));
    m_descriptionCtrl = new wxTextCtrl(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxSize(250, 150), wxTE_MULTILINE | wxHSCROLL);
    gridSizer->Add(m_descriptionCtrl, wxSizerFlags().Expand().Align(wxALIGN_CENTER_VERTICAL).Border(wxUP, 5));

    if(!m_editing)
    {
        gridSizer->Add(new wxStaticText(this, wxID_ANY, _("Subtask of:")), wxSizerFlags().Align(wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL).Border(wxLEFT | wxUP, 5));
        m_tasks = new Tree(this, wxID_ANY);
        m_tasks->updateData();
        gridSizer->Add(m_tasks, wxSizerFlags().Expand().Align(wxALIGN_CENTER_VERTICAL).Border(wxUP, 5));
    }
    
    m_mainSizer->Add(gridSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);
    
    wxStdDialogButtonSizer *btnSizer = new wxStdDialogButtonSizer();
    wxButton* okButton = new wxButton(this, wxID_OK, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(okButton);
    wxButton* cancelButton = new wxButton(this, wxID_CANCEL, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(cancelButton);
    btnSizer->Realize();
    m_mainSizer->Add(btnSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);

    this->SetSizer(m_mainSizer);
}

void TaskDialog::fillControls()
{
    Task task = idbmodel->getTask(m_taskid);
    m_nameCtrl->SetValue(task.name());
    m_descriptionCtrl->SetValue(task.description());
}

void TaskDialog::OnOk(wxCommandEvent& /*event*/)
{
    if(m_editing)
    {
        if(m_nameCtrl->GetValue().IsEmpty())
        {
            return;
        }
        Task task = idbmodel->getTask(m_taskid);
        idbmodel->editTask(Task(task.id(), m_nameCtrl->GetValue(), m_descriptionCtrl->GetValue(), task.tree()));
    }
    else
    {
        if(m_nameCtrl->GetValue().IsEmpty())
        {
            return;
        }
        int parentid = -1;
        if(m_tasks->GetFocusedItem().IsOk())
        {
            parentid = dynamic_cast<IdItemData*>(m_tasks->GetItemData(m_tasks->GetFocusedItem()))->id();
        }
        wxString tree;
        if(parentid == -1)
        {
            tree = ".-1";
        }
        else
        {
            tree << idbmodel->getTask(parentid).tree() << "." << parentid;
        }
        idbmodel->addTask(Task(idbmodel->getLastId("task"), m_nameCtrl->GetValue(), m_descriptionCtrl->GetValue(), tree));
    }
    EndModal(wxID_OK);
}

void TaskDialog::OnCancel(wxCommandEvent& /*event*/)
{
    EndModal(wxID_CANCEL);
}
