/***************************************************************
 * Name:      tree.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#include "tree.h"
#include "model/dbmodel.h"
#include <stack>

Tree::Tree(wxWindow* parent, wxWindowID id)
    : wxTreeCtrl(parent, id, wxDefaultPosition, wxSize(200,150), wxTR_SINGLE|wxTR_NO_LINES|wxTR_HAS_BUTTONS)
{
}

void Tree::updateData()
{
    DeleteAllItems();
    
    wxTreeItemId root = GetRootItem();
    root = AddRoot(_("Tasks"));
    SetItemData(root, new IdItemData(-1));
    SetFocus();
    
    wxTreeItemId taskItem;
    dxTaskArray tasks = idbmodel->tasks();
    for(size_t i=0; i < tasks.GetCount(); i++)
    {
        if(tasks[i].id() == -1) continue;
        taskItem = AppendItem(getItem(tasks[i].tree()), tasks[i].name());
        SetItemData(taskItem, new IdItemData(tasks[i].id()));
    }
    
    Expand(root);
    SelectItem(root);
}

wxTreeItemId Tree::getItem(const wxString &tree)
{
    int id = wxAtoi(tree.AfterLast('.'));
    if(id == -1)
    {
        return GetRootItem();
    }
    std::stack<wxTreeItemId> items;
    if(GetRootItem().IsOk())
        items.push(GetRootItem());
    while(!items.empty())
    {
        wxTreeItemId next = items.top();
        items.pop();
        if(next != GetRootItem()
                && dynamic_cast<IdItemData*>(GetItemData(next))
                && (dynamic_cast<IdItemData*>(GetItemData(next)))->id() == id)
        {
            return next;
        }
        wxTreeItemIdValue cookie;
        wxTreeItemId nextChild = GetFirstChild(next, cookie);
        while(nextChild.IsOk())
        {
            items.push(nextChild);
            nextChild = GetNextSibling(nextChild);
        }
    }
    return GetRootItem();
}

wxTreeItemId Tree::getItem(int id)
{
    if(id == -1)
    {
        return GetRootItem();
    }
    std::stack<wxTreeItemId> items;
    if(GetRootItem().IsOk())
        items.push(GetRootItem());
    while(!items.empty())
    {
        wxTreeItemId next = items.top();
        items.pop();
        if(next != GetRootItem()
                && dynamic_cast<IdItemData*>(GetItemData(next))
                && (dynamic_cast<IdItemData*>(GetItemData(next)))->id() == id)
        {
            return next;
        }
        wxTreeItemIdValue cookie;
        wxTreeItemId nextChild = GetFirstChild(next, cookie);
        while(nextChild.IsOk())
        {
            items.push(nextChild);
            nextChild = GetNextSibling(nextChild);
        }
    }
    return GetRootItem();
}

void Tree::selectID(int id)
{
    std::stack<wxTreeItemId> items;
    if(GetRootItem().IsOk())
        items.push(GetRootItem());
    while(!items.empty())
    {
        wxTreeItemId next = items.top();
        items.pop();
        if(next != GetRootItem()
                && dynamic_cast<IdItemData*>(GetItemData(next))
                && (dynamic_cast<IdItemData*>(GetItemData(next)))->id() == id)
        {
            UnselectAll();
            SelectItem(next);
            EnsureVisible(next);
            return;
        }
        wxTreeItemIdValue cookie;
        wxTreeItemId nextChild = GetFirstChild(next, cookie);
        while(nextChild.IsOk())
        {
            items.push(nextChild);
            nextChild = GetNextSibling(nextChild);
        }
    }
}

wxArrayInt Tree::childsID(int id)
{
    wxArrayInt childs;
    wxTreeItemId parent = getItem(id);
    if(parent.IsOk() && ItemHasChildren(parent))
    {
        wxTreeItemIdValue cookie;
        wxTreeItemId child = GetFirstChild(parent, cookie);
        while(child.IsOk())
        {
            childs.Add((dynamic_cast<IdItemData*>(GetItemData(child)))->id());
            if(ItemHasChildren(child))
            {
                wxArrayInt arr = childsID((dynamic_cast<IdItemData*>(GetItemData(child)))->id());
                for(size_t i=0; i < arr.GetCount(); i++)
                {
                    childs.Add(arr[i]);
                }
            }
            child = GetNextSibling(child);
        }
    }
    return childs;
}
