/***************************************************************
 * Name:      detail.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#include "detail.h"
#include "model/dbmodel.h"
#include "gui/dialogs/recorddialog.h"
#include "utils/dxicons.h"
#include "utils/settings.h"

wxDEFINE_EVENT(RECORD_STARTED, wxCommandEvent);
wxDEFINE_EVENT(RECORD_PAUSED, wxCommandEvent);
wxDEFINE_EVENT(RECORD_TIMER, wxCommandEvent);

void DetailCtrl::CreateColumns()
{
    InsertColumn(DCOL_START, _("Start"));
    InsertColumn(DCOL_END, _("End"));
    InsertColumn(DCOL_TIME, _("Time"));
    if(settings.showSubtasks()) InsertColumn(DCOL_TASK, _("Task"));
    setResizeColumn(DCOL_TIME);
    SetColumnWidth(DCOL_START, 175);
    SetColumnWidth(DCOL_END, 175);
    if(settings.showSubtasks()) SetColumnWidth(DCOL_TASK, 175);
}

wxString DetailCtrl::OnGetItemText(long item, long column) const
{
    return m_page->getItemText(item, column);
}

int DetailCtrl::OnGetItemColumnImage(long /*item*/, long /*column*/) const
{
    return -1;
}

wxListItemAttr *DetailCtrl::OnGetItemAttr(long /*item*/) const
{
    return NULL;
}

BEGIN_EVENT_TABLE(Detail, wxPanel)
    EVT_MENU(ID_DETAILADD, Detail::OnAdd)
    EVT_MENU(ID_DETAILEDIT, Detail::OnEdit)
    EVT_MENU(ID_DETAILDELETE, Detail::OnDelete)
    EVT_LIST_ITEM_RIGHT_CLICK(ID_DETAILCTRL, Detail::OnItemRightClick)
    EVT_LIST_ITEM_ACTIVATED(ID_DETAILCTRL, Detail::OnItemActivated)
    EVT_LIST_ITEM_SELECTED(ID_DETAILCTRL, Detail::OnItemSelected)
    EVT_LIST_ITEM_DESELECTED(ID_DETAILCTRL, Detail::OnItemDeselected)
    EVT_LIST_COL_CLICK(ID_DETAILCTRL, Detail::OnColumnClick)
    EVT_RADIOBOX(ID_DETAILRADIO, Detail::OnShow)
    EVT_BUTTON(ID_DETAILRECORD, Detail::OnRecord)
    EVT_BUTTON(ID_DETAILPAUSE, Detail::OnPause)
    EVT_TIMER(wxID_ANY, Detail::OnTimer)
    EVT_CHECKBOX(ID_DETAILSUBTASKS, Detail::OnShowSubtasks)
END_EVENT_TABLE()

Detail::Detail(wxWindow *parent)
    : wxPanel(parent), m_selected(-1), m_sortCol(DetailCtrl::DCOL_DEF_SORT),
        m_sortAsc(true), m_timeid(-1), m_taskid(-1), m_timer(this)
{
    m_mainSizer = new wxBoxSizer(wxVERTICAL);
    m_text = new wxStaticText(this, wxID_ANY, wxEmptyString);
    m_mainSizer->Add(m_text, 0, wxALL|wxEXPAND, 5);
    wxArrayString choices;
    choices.Add(_("Today"));
    choices.Add(_("This week"));
    choices.Add(_("This month"));
    choices.Add(_("All"));
    m_show = new wxRadioBox(this, ID_DETAILRADIO, _("Show records"), wxDefaultPosition, wxDefaultSize, choices);
    m_mainSizer->Add(m_show, 0, wxALL, 5);
    m_showSubtasks = new wxCheckBox(this, ID_DETAILSUBTASKS, _("Show records for subtasks"));
    m_showSubtasks->SetValue(settings.showSubtasks());
    m_mainSizer->Add(m_showSubtasks, 0, wxALL, 5);
    m_bar = new wxToolBar(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTB_HORIZONTAL|wxTB_FLAT|wxTB_NODIVIDER);
    m_bar->AddTool(ID_DETAILADD, wxEmptyString, ICO_ADD, ICO_GADD, wxITEM_NORMAL, _("Add time"));
    m_bar->AddTool(ID_DETAILEDIT, wxEmptyString, ICO_EDIT, ICO_GEDIT, wxITEM_NORMAL, _("Edit time"));
    m_bar->AddTool(ID_DETAILDELETE, wxEmptyString, ICO_DELETE, ICO_GDELETE, wxITEM_NORMAL, _("Delete time"));
    m_bar->Realize();
    m_mainSizer->Add(m_bar, 0, wxALL|wxEXPAND, 5);
    wxSize imageSize(16, 16);
    m_imageList.reset(new wxImageList(imageSize.GetWidth(), imageSize.GetHeight()));
    m_imageList->Add(ICO_ASC);
    m_imageList->Add(ICO_DESC);
#if defined (__WXGTK__) || defined (__WXMAC__)
    wxPanel *panel1= new wxPanel(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxBORDER_SUNKEN);
#else
    wxPanel *panel1= new wxPanel(this);
#endif
    wxBoxSizer *sizer1 = new wxBoxSizer(wxVERTICAL);
    m_list = new DetailCtrl(this, panel1, ID_DETAILCTRL);
    m_list->SetImageList(m_imageList.get(), wxIMAGE_LIST_SMALL);
    m_list->CreateColumns();
    sizer1->Add(m_list, 1, wxALL|wxEXPAND, 0);
    panel1->SetSizer(sizer1);
    sizer1->Fit(panel1);
    sizer1->SetSizeHints(panel1);
    m_mainSizer->Add(panel1, 1, wxALL|wxEXPAND, 5);
    updateList();
    wxBoxSizer *buttons = new wxBoxSizer(wxHORIZONTAL);
    m_start = new wxBitmapButton(this, ID_DETAILRECORD, ICO_PLAY);
    m_start->SetToolTip(_("Start recording"));
    m_start->SetBitmapDisabled(ICO_GPLAY);
    buttons->Add(m_start);
    buttons->AddSpacer(5);
    m_pause = new wxBitmapButton(this, ID_DETAILPAUSE, ICO_PAUSE);
    m_pause->SetToolTip(_("Pause recording"));
    m_pause->SetBitmapDisabled(ICO_GPAUSE);
    m_pause->Disable();
    buttons->Add(m_pause);
    m_mainSizer->Add(buttons, 0, wxALIGN_CENTER, 5);
    m_mainSizer->AddSpacer(5);
    this->SetSizer(m_mainSizer);
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

Detail::~Detail()
{
    if(m_timer.IsRunning())
        m_timer.Stop();
}

void Detail::updateData(int taskid)
{
    m_taskid = taskid;
    updateText();
    updateList();

    m_mainSizer->Layout();
}

wxString Detail::getItemText(long item, long column) const
{
    if(item < 0 || item >= (int)m_times.GetCount())
        return "";
    switch(column)
    {
    case DetailCtrl::DCOL_START:
        return m_times[item].start().Format("%x %X");
    case DetailCtrl::DCOL_END:
        return m_times[item].end().Format("%x %X");
    case DetailCtrl::DCOL_TIME:
    {
        if(m_times[item].id() == m_timeid) return _("Running");
        else return idbmodel->getTimeString(m_times[item].id());
    }
    case DetailCtrl::DCOL_TASK:
        return idbmodel->taskName(m_times[item].taskid());
    default:
        return "";
    }
}

void Detail::OnAdd(wxCommandEvent &/*event*/)
{
    RecordDialog dialog(m_taskid, this);
    if(dialog.ShowModal() == wxID_OK)
    {
        updateData(m_taskid);
    }
}

void Detail::OnEdit(wxCommandEvent &/*event*/)
{
    RecordDialog dialog(this, m_times[m_selected].id());
    if(dialog.ShowModal() == wxID_OK)
    {
        updateData(m_taskid);
    }
}

void Detail::OnDelete(wxCommandEvent &/*event*/)
{
    wxString text = _("Start");
    text << ": ";
    text << m_times[m_selected].start().Format("%x %X");
    text << "\n";
    text << _("End");
    text << ": ";
    text << m_times[m_selected].end().Format("%x %X");
    text << "\n";
    text << _("Time");
    text << ": ";
    if(m_times[m_selected].id() == m_timeid) text << _("Running");
    else text << idbmodel->getTimeString(m_times[m_selected].id());
    text << "\n";
    if(settings.showSubtasks())
    {
        text << _("Task");
        text << ": ";
        text << idbmodel->taskName(m_times[m_selected].taskid());
    }
    wxMessageDialog dialog(this, wxString::Format(_("Really delete record\n%s"), text), _("Question"), wxOK|wxCANCEL|wxICON_QUESTION);
    if(dialog.ShowModal() == wxID_OK)
    {
        idbmodel->deleteTime(m_times[m_selected].id());
        updateData(m_taskid);
    }
}

void Detail::OnItemRightClick(wxListEvent &event)
{
    m_selected = event.GetIndex();
    enableTools();
    if(!m_timer.IsRunning())
    {
        wxMenu popup;
        popup.Append(ID_DETAILADD, _("New record"));
        if(m_selected != -1)
        {
            popup.Append(ID_DETAILEDIT, _("Edit record"));
            popup.Append(ID_DETAILDELETE, _("Delete record"));
        }
        m_list->PopupMenu(&popup);
    }
}

void Detail::OnItemActivated(wxListEvent &event)
{
    m_selected = event.GetIndex();
    enableTools();
    RecordDialog dialog(this, m_times[m_selected].id());
    if(dialog.ShowModal() == wxID_OK)
    {
        updateData(m_taskid);
    }
}

void Detail::OnItemSelected(wxListEvent &event)
{
    m_selected = event.GetIndex();
    enableTools();
}

void Detail::OnItemDeselected(wxListEvent &/*event*/)
{
    m_selected = -1;
    enableTools();
}

void Detail::OnColumnClick(wxListEvent &event)
{
    if(0 > event.GetColumn() || event.GetColumn() >= DetailCtrl::DCOL_MAX) return;
    setColumnImage(m_sortCol, -1);
    m_sortCol = static_cast<DetailCtrl::DColumn>(event.GetColumn());
    m_sortAsc = !m_sortAsc;
    updateList();
}

void Detail::OnShow(wxCommandEvent &/*event*/)
{
    updateList();
}

void Detail::OnRecord(wxCommandEvent &/*event*/)
{
    m_timeid = idbmodel->getLastId("time");
    idbmodel->addTime(Time(m_timeid, wxDateTime::Now(), wxDateTime::Now(), m_taskid));
    m_timer.Start(60000);
    updateList();
    m_start->Disable();
    m_pause->Enable();
    wxCommandEvent event(RECORD_STARTED);
    wxString tip = "dxTime\n";
    tip << _("Recording:") << " " << idbmodel->getTask(m_taskid).name() << "\n"
        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_TODAY, true).Format("%H:%M ") << _("today") << "\n"
        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_MONTH, true).Format("%H:%M ") << _("this month");
    event.SetString(tip);
    wxPostEvent(GetParent(), event);
}

void Detail::OnPause(wxCommandEvent &/*event*/)
{
    if(m_timer.IsRunning())
    {
        m_timer.Stop();
        idbmodel->setEndTime(m_timeid, wxDateTime::Now());
        updateData(m_taskid);
        m_start->Enable();
        m_pause->Disable();
        m_timeid = -1;
    }
    wxCommandEvent event(RECORD_PAUSED);
    wxPostEvent(GetParent(), event);
}

void Detail::OnTimer(wxTimerEvent &/*event*/)
{
    wxDateTime now = wxDateTime::Now();
    if(now.GetHour()==0 && now.GetMinute()==0)
    {
        m_timeid = idbmodel->getLastId("time");
        idbmodel->addTime(Time(m_timeid, now, now, m_taskid));
    }
    else
    {
        idbmodel->setEndTime(m_timeid, now);
    }
    updateData(m_taskid);
    wxCommandEvent event(RECORD_TIMER);
    wxString tip = "dxTime\n";
    tip << _("Recording:") << " " << idbmodel->getTask(m_taskid).name() << "\n"
        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_TODAY, true).Format("%H:%M ") << _("today") << "\n"
        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_MONTH, true).Format("%H:%M ") << _("this month");
    event.SetString(tip);
    wxPostEvent(GetParent(), event);
}

void Detail::OnShowSubtasks(wxCommandEvent &/*event*/)
{
    if(m_showSubtasks->GetValue())
    {
        m_list->InsertColumn(DetailCtrl::DCOL_TASK, _("Task"));
        m_list->SetColumnWidth(DetailCtrl::DCOL_TASK, 175);
    }
    else
    {
        m_list->DeleteColumn(DetailCtrl::DCOL_TASK);
        m_sortCol = DetailCtrl::DCOL_DEF_SORT;
    }
    settings.setShowSubtasks(m_showSubtasks->GetValue());
    m_list->resize();
    updateList();
}

void Detail::enableTools()
{
    if(m_timer.IsRunning())
    {
        m_bar->EnableTool(ID_DETAILADD, false);
        m_bar->EnableTool(ID_DETAILEDIT, false);
        m_bar->EnableTool(ID_DETAILDELETE, false);
    }
    else
    {
        m_bar->EnableTool(ID_DETAILADD, true);
        if(m_selected == -1)
        {
            m_bar->EnableTool(ID_DETAILEDIT, false);
            m_bar->EnableTool(ID_DETAILDELETE, false);
        }
        else
        {
            m_bar->EnableTool(ID_DETAILEDIT, true);
            m_bar->EnableTool(ID_DETAILDELETE, true);
        }
    }
}

DbModel::TimeSort Detail::columnToTimeSort(DetailCtrl::DColumn column)
{
    switch(column)
    {
    case DetailCtrl::DCOL_START: return DbModel::TIS_START;
    case DetailCtrl::DCOL_END: return DbModel::TIS_END;
    case DetailCtrl::DCOL_TIME: return DbModel::TIS_TIME;
    case DetailCtrl::DCOL_TASK: return DbModel::TIS_TASK;
    default: return DbModel::TIS_START;
    }
}

void Detail::setColumnImage(DetailCtrl::DColumn column, int image)
{
    wxListItem item;
    item.SetMask(wxLIST_MASK_IMAGE);
    item.SetImage(image);
    m_list->SetColumn(column, item);
}

void Detail::updateText()
{
    wxString label;
    if(m_taskid == -1)
    {
        label << _("Tasks") << "\n"
                << _("Time:") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_TODAY, false).Format("%H:%M ") << _("today") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_WEEK, false).Format("%H:%M ") << _("this week") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_MONTH, false).Format("%H:%M ") << _("this month") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_ALL, false).Format("%D:%H:%M ") << _("all");
    }
    else
    {
        Task task = idbmodel->getTask(m_taskid);
        if(task.description().IsEmpty())
        {
            label << task.name() << "\n";
        }
        else
        {
            label << task.name() << "\n" << _("Description:") << "\n" << task.description() << "\n";
        }
        label << _("Time:") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_TODAY, false).Format("%H:%M ") << _("today") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_WEEK, false).Format("%H:%M ") << _("this week") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_MONTH, false).Format("%H:%M ") << _("this month") << "\n"
                << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_ALL, false).Format("%D:%H:%M ") << _("all");
                if(idbmodel->hasSubtasks(m_taskid))
                {
                    label << "\n" << _("Time with subtasks:") << "\n"
                        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_TODAY, true).Format("%H:%M ") << _("today") << "\n"
                        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_WEEK, true).Format("%H:%M ") << _("this week") << "\n"
                        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_MONTH, true).Format("%H:%M ") << _("this month") << "\n"
                        << idbmodel->timeSpanForTask(m_taskid, DbModel::TS_ALL, true).Format("%D:%H:%M ") << _("all");
                }
    }
    m_text->SetLabelText(label);
}

void Detail::updateList()
{
    setColumnImage(m_sortCol, m_sortAsc?0:1);
    m_times = idbmodel->timesByTaks(m_taskid, (DbModel::TimeSum)m_show->GetSelection(), settings.showSubtasks());
    idbmodel->sortTime(m_times, columnToTimeSort(m_sortCol), m_sortAsc);
    size_t cnt = m_times.GetCount();
    m_list->SetItemCount(cnt);
    if(cnt)
    {
        if(static_cast<size_t>(m_selected) >= cnt)
        {
            m_list->SetItemState(0, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
            m_selected = 0;
        }
        m_list->RefreshItems(0, cnt > 0 ? --cnt : 0);
    }
    else
    {
        m_list->Refresh();
        m_selected = -1;
    }
    enableTools();
}

void Detail::stopRecord()
{
    if(m_timer.IsRunning())
    {
        m_timer.Stop();
        idbmodel->setEndTime(m_timeid, wxDateTime::Now());
        m_timeid = -1;
    }
    m_start->Enable();
    m_pause->Disable();
}

bool Detail::isRecording()
{
    return m_timer.IsRunning();
}

void Detail::recordPause()
{
    wxCommandEvent event;
    if(isRecording())
    {
        OnPause(event);
    }
    else
    {
        OnRecord(event);
    }
}
