/***************************************************************
 * Name:      detail.h
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#ifndef DETAIL_H
#define DETAIL_H

#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif
#include <wx/imaglist.h>
#include "gui/widgets/dxlistctrl.h"
#include "dxdefs.h"
#include "model/dbmodel.h"

wxDECLARE_EVENT(RECORD_STARTED, wxCommandEvent);
wxDECLARE_EVENT(RECORD_PAUSED, wxCommandEvent);
wxDECLARE_EVENT(RECORD_TIMER, wxCommandEvent);

class Detail;

class DetailCtrl: public dxListCtrl
{
public:
    DetailCtrl(Detail *page, wxWindow *parent, const wxWindowID id)
        : dxListCtrl(parent, id), m_page(page) {}

    enum DColumn
    {
        DCOL_START = 0,
        DCOL_END,
        DCOL_TIME,
        DCOL_TASK,
        DCOL_MAX, // pocet sloupcu
        DCOL_DEF_SORT = DCOL_START
    };

    void CreateColumns();
private:
    Detail *m_page;

    virtual wxString OnGetItemText(long item, long column) const;
    virtual int OnGetItemColumnImage(long item, long column) const;
    virtual wxListItemAttr *OnGetItemAttr(long item) const;
};

class Detail : public wxPanel
{
    DECLARE_EVENT_TABLE()
public:
    Detail(wxWindow *parent);
    ~Detail();

    void updateData(int taskid);
    wxString getItemText(long item, long column) const;
    void stopRecord();
    bool isRecording();
    void recordPause();
private:
    wxBoxSizer *m_mainSizer;
    wxStaticText *m_text;
    DetailCtrl *m_list;
    long m_selected;
    wxToolBar *m_bar;
    DetailCtrl::DColumn m_sortCol;
    bool m_sortAsc;
    wxScopedPtr<wxImageList> m_imageList;
    dxTimeArray m_times;
    int m_timeid;
    int m_taskid;
    wxBitmapButton *m_start;
    wxBitmapButton *m_pause;
    wxRadioBox *m_show;
    wxTimer m_timer;
    wxCheckBox *m_showSubtasks;

    void OnAdd(wxCommandEvent& event);
    void OnEdit(wxCommandEvent& event);
    void OnDelete(wxCommandEvent& event);
    void OnItemRightClick(wxListEvent& event);
    void OnItemActivated(wxListEvent& event);
    void OnItemSelected(wxListEvent& event);
    void OnItemDeselected(wxListEvent& event);
    void OnColumnClick(wxListEvent& event);
    void OnShow(wxCommandEvent& event);
    void OnRecord(wxCommandEvent& event);
    void OnPause(wxCommandEvent& event);
    void OnTimer(wxTimerEvent& event);
    void OnShowSubtasks(wxCommandEvent& event);
    void enableTools();
    DbModel::TimeSort columnToTimeSort(DetailCtrl::DColumn column);
    void setColumnImage(DetailCtrl::DColumn column, int image);
    void updateText();
    void updateList();
};

#endif  /* DETAIL_H */

