/***************************************************************
 * Name:      dbsort.h
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2015
 * License:   GPL3
 **************************************************************/

#ifndef DBSORT_H
#define DBSORT_H

#include "dbmodel.h"

static int dxSortTimeByIdAsc(Time **t1, Time **t2)
{
    if((*t1)->id() == (*t2)->id())
        return 0;
    if((*t1)->id() < (*t2)->id())
        return -1;
    return 1;
}

static int dxSortTimeByIdDsc(Time **d1, Time **d2)
{
    if((*d1)->id() == (*d2)->id())
        return 0;
    if((*d1)->id() < (*d2)->id())
        return 1;
    return -1;
}

static int dxSortTimeByStartAsc(Time **t1, Time **t2)
{
    if((*t1)->start().IsEarlierThan((*t2)->start()))
        return -1;
    return 1;
}

static int dxSortTimeByStartDsc(Time **t1, Time **t2)
{
    if((*t1)->start().IsEarlierThan((*t2)->start()))
        return 1;
    return -1;
}

static int dxSortTimeByEndAsc(Time **t1, Time **t2)
{
    if((*t1)->end().IsEarlierThan((*t2)->end()))
        return -1;
    return 1;
}

static int dxSortTimeByEndDsc(Time **t1, Time **t2)
{
    if((*t1)->end().IsEarlierThan((*t2)->end()))
        return 1;
    return -1;
}

static int dxSortTimeByTimeAsc(Time **t1, Time **t2)
{
    int m1 = idbmodel->getMinutes((*t1)->id());
    int m2 = idbmodel->getMinutes((*t2)->id());
    if(m1 == m2)
        return dxSortTimeByIdAsc(t1,t2);
    if(m1 < m2)
        return -1;
    return 1;
}

static int dxSortTimeByTimeDsc(Time **t1, Time **t2)
{
    int m1 = idbmodel->getMinutes((*t1)->id());
    int m2 = idbmodel->getMinutes((*t2)->id());
    if(m1 == m2)
        return dxSortTimeByIdDsc(t1,t2);
    if(m1 < m2)
        return 1;
    return -1;
}

static int dxSortTimeByTaskAsc(Time **t1, Time **t2)
{
    wxString s1 = idbmodel->taskName((*t1)->taskid());
    wxString s2 = idbmodel->taskName((*t2)->taskid());
    if(s1 == s2)
        return dxSortTimeByIdAsc(t1,t2);
    return s1.CmpNoCase(s2);
}

static int dxSortTimeByTaskDsc(Time **t1, Time **t2)
{
    wxString s1 = idbmodel->taskName((*t1)->taskid());
    wxString s2 = idbmodel->taskName((*t2)->taskid());
    if(s1 == s2)
        return dxSortTimeByIdDsc(t1,t2);
    return s2.CmpNoCase(s1);
}

static int dxSortTaskByIdAsc(Task **t1, Task **t2)
{
    if((*t1)->id() == (*t2)->id())
        return 0;
    if((*t1)->id() < (*t2)->id())
        return -1;
    return 1;
}

static int dxSortTaskByIdDsc(Task **d1, Task **d2)
{
    if((*d1)->id() == (*d2)->id())
        return 0;
    if((*d1)->id() < (*d2)->id())
        return 1;
    return -1;
}

static int dxSortTaskByTreeAsc(Task **t1, Task **t2)
{
    size_t l1 = (*t1)->tree().Len();
    size_t l2 = (*t2)->tree().Len();
    if(l1 == l2)
        return dxSortTaskByIdAsc(t1,t2);
    if(l1 < l2)
        return -1;
    return 1;
}

static int dxSortTaskByTreeDsc(Task **t1, Task **t2)
{
    size_t l1 = (*t1)->tree().Len();
    size_t l2 = (*t2)->tree().Len();
    if(l1 == l2)
        return dxSortTaskByIdDsc(t1,t2);
    if(l1 < l2)
        return 1;
    return -1;
}

#endif  /* DBSORT_H */
