/***************************************************************
 * Name:      dxicons.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2020
 * License:   GPL3
 **************************************************************/

#include <wx/icon.h>
#include <wx/image.h>
#include <wx/bitmap.h>
#include <wx/mstream.h>
#include <wx/fileconf.h>
#include <wx/stdpaths.h>
#include "dxicons.h"

static const char *const  empty[] = {
"16 16 11 1",
"   c None",
".  c #000000",
"+  c #FFFFFF",
"@  c #FDE4E4",
"#  c #F45C5C",
"$  c #EF0B0B",
"%  c #F12727",
"&  c #F67878",
"*  c #FAAEAE",
"=  c #FBC9C9",
"-  c #F89393",
"................",
".++++++++++++++.",
".++++++++++++++.",
".++++@#$$%&++++.",
".+++@%$$$$$&+++.",
".+++&$$#*%$$+++.",
".+++=-#+@%$%+++.",
".++++++@%$$*+++.",
".++++++%$%@++++.",
".+++++*$$*+++++.",
".+++++@**@+++++.",
".+++++*$$*+++++.",
".+++++*$$*+++++.",
".+++++@**@+++++.",
".++++++++++++++.",
"................"};

static const char * dxtime_xpm[] = {
"48 48 431 2",
"   c None",
".  c #DCDCDA",
"+  c #E2E2DF",
"@  c #E0E1DE",
"#  c #D9DAD5",
"$  c #CFD1CB",
"%  c #DADBD8",
"&  c #B9BAB5",
"*  c #969994",
"=  c #939691",
"-  c #B4B6B2",
";  c #DCDDDA",
">  c #D3D5D0",
",  c #C4C6C3",
"'  c #CFD1CD",
")  c #878984",
"!  c #888A86",
"~  c #D2D3CF",
"{  c #C9CBC8",
"]  c #CFD0CC",
"^  c #91938E",
"/  c #939490",
"(  c #D0D1CD",
"_  c #C4C5C1",
":  c #C4C5C2",
"<  c #A8ABA7",
"[  c #B5B8B3",
"}  c #B6B9B4",
"|  c #BBBCB8",
"1  c #B3B4B1",
"2  c #B7BAB5",
"3  c #B4B7B2",
"4  c #A8AAA5",
"5  c #959692",
"6  c #B8B9B6",
"7  c #979C97",
"8  c #B5B7B2",
"9  c #A5A6A2",
"0  c #A1A29E",
"a  c #BEC1BB",
"b  c #BCBDB9",
"c  c #949592",
"d  c #C5C5C1",
"e  c #C1C1BE",
"f  c #969793",
"g  c #B7B8B5",
"h  c #BBBCBA",
"i  c #B5B5B2",
"j  c #B7B9B4",
"k  c #979996",
"l  c #A1A3A1",
"m  c #BFC0BD",
"n  c #949792",
"o  c #EEEEEC",
"p  c #E6E6E4",
"q  c #8F918B",
"r  c #BFC0BE",
"s  c #A6A7A5",
"t  c #81827E",
"u  c #A0A39F",
"v  c #A0A19D",
"w  c #81827F",
"x  c #888B86",
"y  c #82837E",
"z  c #CFD2CA",
"A  c #CFD3CB",
"B  c #BEC1BA",
"C  c #DDDFDA",
"D  c #D9DBD5",
"E  c #BEC2BB",
"F  c #CBCFC8",
"G  c #D7DAD3",
"H  c #E7E9E5",
"I  c #EEF0EE",
"J  c #F3F4F2",
"K  c #F7F7F6",
"L  c #C8CCC4",
"M  c #CACDC6",
"N  c #DEE0DC",
"O  c #F1F1F1",
"P  c #F8F8F7",
"Q  c #C4C8C0",
"R  c #D3D5D1",
"S  c #F0F1EF",
"T  c #F5F5F4",
"U  c #C0C3BD",
"V  c #C0C4BC",
"W  c #DADCD8",
"X  c #F1F1F0",
"Y  c #F2F2F1",
"Z  c #EDEDEC",
"`  c #D2D2D0",
" . c #B1B2B1",
".. c #929391",
"+. c #BCC0B9",
"@. c #DEDFDC",
"#. c #EEEEED",
"$. c #D2D3D1",
"%. c #7E807D",
"&. c #5E605C",
"*. c #5B5D59",
"=. c #656763",
"-. c #7C7E7B",
";. c #858175",
">. c #6B6A61",
",. c #5C5D58",
"'. c #B8BCB5",
"). c #D2D3D0",
"!. c #EAEAE9",
"~. c #E8E8E6",
"{. c #A5A6A4",
"]. c #636561",
"^. c #80817C",
"/. c #ABABA8",
"(. c #A9ABA8",
"_. c #CACBC9",
":. c #AEA699",
"<. c #CFBFA7",
"[. c #B0A692",
"}. c #B4A993",
"|. c #898477",
"1. c #B4B8B1",
"2. c #C4C6C1",
"3. c #E4E5E3",
"4. c #E5E5E4",
"5. c #D3D3D1",
"6. c #7F817D",
"7. c #6A6C68",
"8. c #8D8E8C",
"9. c #9C9E9C",
"0. c #D9DAD8",
"a. c #D6D3CB",
"b. c #E8E2D7",
"c. c #DBD7CE",
"d. c #E1D7C6",
"e. c #9D9588",
"f. c #9D937F",
"g. c #6D6D67",
"h. c #B1B4AE",
"i. c #DBDBD9",
"j. c #E0E0DF",
"k. c #DEDEDC",
"l. c #80827D",
"m. c #838580",
"n. c #BEBFBD",
"o. c #D4D5D3",
"p. c #BBBBB8",
"q. c #E1E2DF",
"r. c #DBDBDA",
"s. c #DFD9CF",
"t. c #EAE3D5",
"u. c #EAE3D6",
"v. c #E2DBD0",
"w. c #BDBCB6",
"x. c #DDD1BE",
"y. c #C9B89F",
"z. c #8B887C",
"A. c #ADB0A9",
"B. c #BBBDB8",
"C. c #DADAD8",
"D. c #A2A3A0",
"E. c #767974",
"F. c #B9B9B6",
"G. c #C7C7C4",
"H. c #E4E4E2",
"I. c #D7D7D5",
"J. c #E1E1DF",
"K. c #E9E9E7",
"L. c #ECE3D4",
"M. c #E3DBCE",
"N. c #EDE4D5",
"O. c #E1DACC",
"P. c #DCD5CB",
"Q. c #E8E0D2",
"R. c #C9C4BA",
"S. c #C6B89F",
"T. c #7A7B73",
"U. c #A9ACA6",
"V. c #C2C3C0",
"W. c #D4D4D2",
"X. c #C0C0BE",
"Y. c #777974",
"Z. c #A0A19E",
"`. c #D5D5D3",
" + c #E7E7E5",
".+ c #EBEBE9",
"++ c #ECECEB",
"@+ c #E0E0DD",
"#+ c #EDEDEB",
"$+ c #E5E5E3",
"%+ c #EBE1D0",
"&+ c #EEE4D2",
"*+ c #E2D9CB",
"=+ c #F0E5D4",
"-+ c #EEE4D4",
";+ c #ECE2D3",
">+ c #E8DED0",
",+ c #DFD1BC",
"'+ c #ADA28C",
")+ c #A5A8A2",
"!+ c #ACAEA9",
"~+ c #CBCBCA",
"{+ c #CECECC",
"]+ c #8A8D88",
"^+ c #969892",
"/+ c #7B7C78",
"(+ c #B5B6B4",
"_+ c #DFDFDD",
":+ c #EAEAE8",
"<+ c #ECECEA",
"[+ c #E0E0DE",
"}+ c #E3D8C7",
"|+ c #F0E4D1",
"1+ c #E1D7C7",
"2+ c #EFE4D0",
"3+ c #E3D9C9",
"4+ c #B4B3AC",
"5+ c #868782",
"6+ c #989A95",
"7+ c #A1A59E",
"8+ c #B0B2AE",
"9+ c #BBBCB9",
"0+ c #C1C2BF",
"a+ c #C0C1BF",
"b+ c #80837E",
"c+ c #B9BAB8",
"d+ c #D4D4D1",
"e+ c #CDCECA",
"f+ c #DDDEDB",
"g+ c #DDDDDB",
"h+ c #E0E1DF",
"i+ c #E5D9C7",
"j+ c #EEE1CC",
"k+ c #E0D6C4",
"l+ c #F0E3CE",
"m+ c #DBD2C3",
"n+ c #CFCCC5",
"o+ c #9EA19A",
"p+ c #B2B2AF",
"q+ c #B7B7B5",
"r+ c #B8B8B6",
"s+ c #AFAFAD",
"t+ c #868883",
"u+ c #AAABA7",
"v+ c #CBCBC8",
"w+ c #E5E6E4",
"x+ c #DFDFDE",
"y+ c #EBEBEA",
"z+ c #EEE1CB",
"A+ c #DFD4C2",
"B+ c #EDDFCB",
"C+ c #D7CDBC",
"D+ c #BFBCB5",
"E+ c #E3E2E0",
"F+ c #EFEFEC",
"G+ c #D0D1CF",
"H+ c #B4B5B2",
"I+ c #9A9D97",
"J+ c #B0B1AD",
"K+ c #B2B3B0",
"L+ c #A0A29D",
"M+ c #C9CAC8",
"N+ c #DCDCDB",
"O+ c #EEEEEB",
"P+ c #E2E2E0",
"Q+ c #E8DBC4",
"R+ c #D6CBB8",
"S+ c #A4A29B",
"T+ c #C6C6C3",
"U+ c #D8D8D6",
"V+ c #979995",
"W+ c #969993",
"X+ c #AEAFAB",
"Y+ c #AEAFAC",
"Z+ c #999B96",
"`+ c #A1A49E",
" @ c #ABACA9",
".@ c #BEBFBB",
"+@ c #B9BBB9",
"@@ c #8F8E89",
"#@ c #9D9E9C",
"$@ c #E6E6E5",
"%@ c #B6B7B3",
"&@ c #A5A6A1",
"*@ c #92958F",
"=@ c #AAAAA8",
"-@ c #9B9E97",
";@ c #9E9F9C",
">@ c #8B8C88",
",@ c #999A96",
"'@ c #DBDCD9",
")@ c #959797",
"!@ c #7D8080",
"~@ c #AAACAC",
"{@ c #9D9E9B",
"]@ c #939491",
"^@ c #A2A5A0",
"/@ c #8E918B",
"(@ c #A3A4A1",
"_@ c #A5A6A3",
":@ c #A6A8A2",
"<@ c #CDCDCA",
"[@ c #B6B9B8",
"}@ c #5A5F61",
"|@ c #9EA1A1",
"1@ c #E9E9E8",
"2@ c #A8AAA4",
"3@ c #8A8D87",
"4@ c #9D9E9A",
"5@ c #A1A29F",
"6@ c #A2A59F",
"7@ c #ADAEAA",
"8@ c #C1C2C0",
"9@ c #ECECE9",
"0@ c #DDDEDC",
"a@ c #D1D2D1",
"b@ c #EFEFED",
"c@ c #C7C8C4",
"d@ c #949692",
"e@ c #9C9D9A",
"f@ c #9D9F9B",
"g@ c #A6A9A2",
"h@ c #C3C3C0",
"i@ c #D5D6D4",
"j@ c #D4D5D2",
"k@ c #CFCFCB",
"l@ c #898C87",
"m@ c #989996",
"n@ c #BABAB6",
"o@ c #969895",
"p@ c #6D706B",
"q@ c #C9C9C8",
"r@ c #C8C8C6",
"s@ c #6D6F6C",
"t@ c #BEC0BB",
"u@ c #80837D",
"v@ c #939591",
"w@ c #9EA09C",
"x@ c #B0B4AD",
"y@ c #959693",
"z@ c #D0D0CE",
"A@ c #D7D7D6",
"B@ c #9C9D9B",
"C@ c #7B7E78",
"D@ c #878884",
"E@ c #8F908D",
"F@ c #AAACA6",
"G@ c #BABCB5",
"H@ c #D7D8D4",
"I@ c #E9E9E6",
"J@ c #BABBB8",
"K@ c #BBBDB6",
"L@ c #777B76",
"M@ c #797B77",
"N@ c #8A8B88",
"O@ c #8B8C89",
"P@ c #B7BAB3",
"Q@ c #B8B9B5",
"R@ c #CACAC6",
"S@ c #DADAD7",
"T@ c #797B78",
"U@ c #C9C9C6",
"V@ c #82837F",
"W@ c #BBBDBA",
"X@ c #737671",
"Y@ c #7C7E7A",
"Z@ c #868884",
"`@ c #BCC1B9",
" # c #C2C6BF",
".# c #A8AAA6",
"+# c #CDCECB",
"@# c #A4A6A2",
"## c #AEAEAC",
"$# c #E6E7E4",
"%# c #D0D1CE",
"&# c #838480",
"*# c #C4C8C1",
"=# c #6F726D",
"-# c #7C7D79",
";# c #828380",
"># c #898A87",
",# c #B2B5AF",
"'# c #C3C6BF",
")# c #C3C5C1",
"!# c #CFD1CE",
"~# c #B5B6B2",
"{# c #9F9F9C",
"]# c #A7A8A6",
"^# c #DCDCD9",
"/# c #B7B8B3",
"(# c #D4D6D3",
"_# c #C5C7C2",
":# c #C4C7C0",
"<# c #6C6E69",
"[# c #7A7C78",
"}# c #7E7F7C",
"|# c #9C9E99",
"1# c #C7CBC3",
"2# c #CBCFC7",
"3# c #CDD0CA",
"4# c #CED0CB",
"5# c #696A66",
"6# c #696A67",
"7# c #737572",
"8# c #8C8F8A",
"9# c #9EA19B",
"0# c #B0B3AD",
"a# c #C2C5BE",
"b# c #646562",
"c# c #646662",
"d# c #6C6E6A",
"e# c #747572",
"f# c #757673",
"g# c #5D605C",
"h# c #60625E",
"i# c #616460",
"j# c #70726E",
"k# c #5D5F5C",
"l# c #595B57",
"m# c #5C5E5A",
"n# c #5D5F5B",
"o# c #626560",
"p# c #676965",
"q# c #6A6C69",
"r# c #525551",
"s# c #575955",
"t# c #585B56",
"u# c #5A5D57",
"v# c #515551",
"w# c #4B4C4B",
"x# c #4E4F4D",
"                                                                                                ",
"                                            . + @ #                                             ",
"                                        $ % & * = - ; >                                         ",
"                                      , ' )         ! ~ {                                       ",
"                                      ] ^             / (                                       ",
"                                      _                 :                                       ",
"                                    < [     } | 1 2     3 4                                     ",
"                                    5 6   7 8 9 0 a     b c                                     ",
"                                      d   7 8 9 0 a     e                                       ",
"                                      f g   [ h i j   6 k                                       ",
"                                        l m n o p q r s                                         ",
"                                          t u o p v w                                           ",
"                                            x o p y                                             ",
"                                      z A A B C D E A A z                                       ",
"                                  F F G H I J K K J I H G F F                                   ",
"                              L M N O P P P P P P P P P P O N M L                               ",
"                            Q R S T T T T T T T T T T T T T T S R Q                             ",
"                        U V W X Y Y Y Y Z `  ..... .` Z Y Y Y Y X W V U                         ",
"                        +.@.#.#.#.#.$.%.&.*.=.-.;.>.,.&.%.$.#.#.#.#.@.+.                        ",
"                      '.).!.!.!.~.{.].^./.(._.s :.<.[.}.|.].{.~.!.!.!.).'.                      ",
"                    1.2.3.4.4.5.6.7.8.9.. 0.p 5.a.b.c.d.e.f.g.6.5.4.4.3.2.1.                    ",
"                    h.i.j.j.k.l.m.n.o.p.q.~.~.r.s.t.u.v.w.x.y.z.l.k.j.j.i.h.                    ",
"                  A.B.C.C.C.D.E.F.G.H.I.J.K.J.p L.M.N.O.P.Q.R.S.T.D.C.C.C.B.A.                  ",
"                  U.V.W.W.X.Y.Z.`.q. +.+++@+#+$+%+&+*+=+-+;+>+,+'+Y.X.W.W.V.U.                  ",
"                )+!+X.~+{+]+^+/+(+_+:+#+<+[+o i.}+|+1+|+|+2+3+4+5+6+]+{+~+X.!+)+                ",
"                7+8+9+0+a+b+c+d+e+f+<+#+#+g+#+h+i+j+k+l+l+m+n+d+_+r b+a+0+9+8+7+                ",
"                o+p+q+r+s+t+u+v+w+!.o o o !.x+y+z+A+B+C+D+E+F+.+G+H+t+s+r+q+p+o+                ",
"                I+J+K+K+L+* M+N+p <+O+O+O+O+:+P+Q+R+S+T+F+F+F+#+H.U+V+L+K+K+J+I+                ",
"                W+X+Y+Y+Z+`+ @.@q.#+o o o o o +@@@#@$@#.#.#.#.$+_ %@&@Z+Y+Y+X+W+                ",
"                *@=@=@=@-@;@>@,@'@o o o o g+)@!@~@#.#.#.#.#.#.; {@]@^@-@=@=@=@*@                ",
"                /@(@_@_@L+:@<@i.p #+Z Z [@}@|@1@Z Z Z Z Z Z #.o 4.i.2@L+_@_@(@/@                ",
"                3@4@5@5@0 6@7@8@H.9@o o 0@a@o o o o o o b@b@Z .+c@g 6@0 5@5@4@3@                ",
"                ) d@e@e@f@g@h@i@j@J.o o o o o o o o o o o F+P+k.J.k@g@f@e@e@d@)                 ",
"                m.l@m@m@m@U.n@o@p@q@<+b@#+O+O+O+F+F+F+o o o r@s@(@t@U.m@m@m@l@m.                ",
"                  u@v@c c w@x@y@z@[+K.o o o o #+#+o o o o o K.A@B@x@w@c c v@u@                  ",
"                  C@D@E@E@E@F@G@<@%@P+H@~.o o o o o o p g+I@J@I.K@F@E@E@E@D@C@                  ",
"                  L@M@N@O@O@E@P@Q@R@S@T@U@:+#+$+p o #+h@V@J.z@W@P@E@O@O@N@M@L@                  ",
"                    X@Y@Z@Z@Z@* `@ #.#! N++#$+@###$#%#q.&#i *#`@* Z@Z@Z@Y@X@                    ",
"                      =#-#;#;#;#>#,#'#)#!#~#S@{#]#^#/#(#_#:#,#>#;#;#;#-#=#                      ",
"                      <#<#[#}#}#}#}#|#1#2#M 3#& B.4#M 2#1#|#}#}#}#}#[#<#<#                      ",
"                        5#6#7#M@M@M@M@Y@8#9#0#a#a#0#9#8#Y@M@M@M@M@7#6#5#                        ",
"                          b#c#d#e#f#f#f#f#f#f#f#f#f#f#f#f#f#f#e#d#c#b#                          ",
"                            g#h#i#7.j#j#j#j#j#j#j#j#j#j#j#j#7.i#h#k#                            ",
"                                l#m#n#o#p#q#d#d#d#d#q#p#o#n#m#l#                                ",
"                                    r#s#t#t#t#u#u#t#t#t#s#v#                                    ",
"                                            w#x#x#w#                                            ",
"                                                                                                ",
"                                                                                                "};

static const char * about_xpm[] = {
"128 128 1244 2",
"   c None",
".  c #D6D8D3",
"+  c #D7D8D5",
"@  c #DADBD6",
"#  c #DADCD6",
"$  c #D9DAD6",
"%  c #D5D7D1",
"&  c #D3D5CD",
"*  c #D4D6D3",
"=  c #D5D5D3",
"-  c #DDDEDB",
";  c #E5E6E4",
">  c #E7E7E5",
",  c #E6E7E5",
"'  c #E2E3E0",
")  c #DDDEDA",
"!  c #D1D3CE",
"~  c #D0D1CE",
"{  c #DEDFDB",
"]  c #E6E6E3",
"^  c #E4E5E2",
"/  c #DCDDDA",
"(  c #D6D7D4",
"_  c #D3D4D0",
":  c #CECFCB",
"<  c #D1D2CD",
"[  c #D5D7D3",
"}  c #D9DAD7",
"|  c #DEDFDC",
"1  c #E3E4E1",
"2  c #E5E6E3",
"3  c #DCDDD9",
"4  c #CFD0CD",
"5  c #CED0CB",
"6  c #D5D5D2",
"7  c #E3E3E1",
"8  c #E1E1DF",
"9  c #D4D5D2",
"0  c #C8C9C4",
"a  c #B8B9B5",
"b  c #A5A5A2",
"c  c #92948F",
"d  c #7F817E",
"e  c #7E817D",
"f  c #90938F",
"g  c #A4A5A0",
"h  c #B7B8B4",
"i  c #C8C9C5",
"j  c #D7D7D3",
"k  c #E2E2E1",
"l  c #E2E3E1",
"m  c #D3D5D1",
"n  c #CDCECB",
"o  c #D5D7D2",
"p  c #E2E2DF",
"q  c #B0B3AD",
"r  c #7B7C78",
"s  c #6B6D69",
"t  c #70736F",
"u  c #797B77",
"v  c #80837D",
"w  c #7A7B78",
"x  c #71736F",
"y  c #6B6D68",
"z  c #B1B3AE",
"A  c #C9CBC7",
"B  c #D7D8D4",
"C  c #E0E1DE",
"D  c #D4D6D1",
"E  c #C5C6C2",
"F  c #C7C9C4",
"G  c #D2D3D0",
"H  c #CFD0CC",
"I  c #C0C2BD",
"J  c #939590",
"K  c #70716C",
"L  c #71736E",
"M  c #969894",
"N  c #C2C4BF",
"O  c #C6C7C4",
"P  c #CACBC7",
"Q  c #DBDCD9",
"R  c #CBCCC8",
"S  c #BABBB6",
"T  c #7A7C78",
"U  c #7C7D7A",
"V  c #7E807B",
"W  c #BDBEB9",
"X  c #CDCEC9",
"Y  c #CACBC8",
"Z  c #BEBEBC",
"`  c #D8D9D6",
" . c #D0D0CD",
".. c #BFC1BC",
"+. c #878A86",
"@. c #8B8D88",
"#. c #C1C2BE",
"$. c #BCBEBA",
"%. c #BEBFBB",
"&. c #CBCDC8",
"*. c #C3C4C1",
"=. c #9EA19D",
"-. c #7D7F7C",
";. c #7E807D",
">. c #A0A39F",
",. c #C3C5C1",
"'. c #CFCFCD",
"). c #CACCC8",
"!. c #B9BAB6",
"~. c #B3B4B1",
"{. c #7E7F79",
"]. c #7E7F7A",
"^. c #B2B4AF",
"/. c #C6C7C2",
"(. c #CCCDC9",
"_. c #B4B6B1",
":. c #BFC1BD",
"<. c #CBCBC9",
"[. c #9B9D99",
"}. c #989B96",
"|. c #BDBFBA",
"1. c #C7C8C4",
"2. c #BBBCB8",
"3. c #B1B3AF",
"4. c #C4C5C1",
"5. c #C8C9C6",
"6. c #B8BAB5",
"7. c #959692",
"8. c #90938D",
"9. c #B3B5B0",
"0. c #C2C3C0",
"a. c #BEC0BC",
"b. c #AFB0AB",
"c. c #ADAEAA",
"d. c #B1B2AD",
"e. c #8F908D",
"f. c #E1E3DF",
"g. c #EAEAE9",
"h. c #8A8B87",
"i. c #ACADA8",
"j. c #BFC0BB",
"k. c #BEBFBA",
"l. c #A8AAA6",
"m. c #AAACA7",
"n. c #C3C4C0",
"o. c #C2C4C0",
"p. c #989993",
"q. c #B4B8B1",
"r. c #C4C8C2",
"s. c #D1D3CD",
"t. c #DFDFDE",
"u. c #D0D1CF",
"v. c #D7D7D5",
"w. c #BCBFBB",
"x. c #B4B4B0",
"y. c #A8ABA5",
"z. c #8E8F89",
"A. c #A4A7A2",
"B. c #BCBEB9",
"C. c #BBBDB9",
"D. c #A6A8A3",
"E. c #A7A9A4",
"F. c #C0C1BD",
"G. c #C1C2BD",
"H. c #A3A5A1",
"I. c #BABDB7",
"J. c #C5C9C2",
"K. c #9A9B96",
"L. c #686A67",
"M. c #B9BAB8",
"N. c #858682",
"O. c #9D9E9B",
"P. c #989A94",
"Q. c #ADADAA",
"R. c #D2D5CE",
"S. c #9FA29D",
"T. c #A1A39F",
"U. c #BBBCB9",
"V. c #BCBDBA",
"W. c #A5A6A2",
"X. c #A2A49F",
"Y. c #BEBFBC",
"Z. c #A7A8A5",
"`. c #BEC2BA",
" + c #969792",
".+ c #5E605C",
"++ c #939490",
"@+ c #A9AAA6",
"#+ c #D2D6CE",
"$+ c #A4A6A1",
"%+ c #A7A8A4",
"&+ c #BDBEBA",
"*+ c #A1A39E",
"=+ c #999C96",
"-+ c #B7B9B5",
";+ c #BCBDB9",
">+ c #BDBEBC",
",+ c #90918E",
"'+ c #B0B1AD",
")+ c #A8A9A5",
"!+ c #ABADA8",
"~+ c #B1B2AF",
"{+ c #91938F",
"]+ c #848681",
"^+ c #BABBB7",
"/+ c #B2B3B0",
"(+ c #A4A5A3",
"_+ c #B3B4B0",
":+ c #A8A9A6",
"<+ c #838582",
"[+ c #797C77",
"}+ c #9D9F9B",
"|+ c #A5A7A4",
"1+ c #A7A9A5",
"2+ c #B6B8B4",
"3+ c #9EA09B",
"4+ c #BABBB8",
"5+ c #ACAEAB",
"6+ c #BFBFBC",
"7+ c #ACADAA",
"8+ c #8A8C87",
"9+ c #737570",
"0+ c #999B96",
"a+ c #A0A19E",
"b+ c #A6A7A4",
"c+ c #C4C4C0",
"d+ c #B5B6B3",
"e+ c #9C9E99",
"f+ c #727472",
"g+ c #70746C",
"h+ c #80817D",
"i+ c #A0A29E",
"j+ c #BCBDBB",
"k+ c #A5A7A3",
"l+ c #ACAFA8",
"m+ c #C0C3BD",
"n+ c #A9ABA7",
"o+ c #939491",
"p+ c #C5C5C2",
"q+ c #9B9C99",
"r+ c #B9BAB7",
"s+ c #A5A7A2",
"t+ c #C7CAC2",
"u+ c #979A95",
"v+ c #BEBFBD",
"w+ c #BBBCBA",
"x+ c #A5A6A3",
"y+ c #82837F",
"z+ c #70726E",
"A+ c #6A6D68",
"B+ c #C2C3C1",
"C+ c #ABACA8",
"D+ c #A7AAA5",
"E+ c #B5B7B1",
"F+ c #D0D2CD",
"G+ c #E8E9E5",
"H+ c #ECECEA",
"I+ c #E9E9E7",
"J+ c #DADAD7",
"K+ c #ACADAB",
"L+ c #C1C2C1",
"M+ c #AAABA8",
"N+ c #8D8F8B",
"O+ c #6C6D69",
"P+ c #6C6E69",
"Q+ c #8F908C",
"R+ c #C3C3C1",
"S+ c #C0C0BD",
"T+ c #A4A5A1",
"U+ c #C9CAC7",
"V+ c #EEEEEC",
"W+ c #E0E0DE",
"X+ c #BDBEBB",
"Y+ c #9A9C98",
"Z+ c #AAABA7",
"`+ c #C4C5C2",
" @ c #C7C7C4",
".@ c #A9AAA7",
"+@ c #8F918E",
"@@ c #6E706B",
"#@ c #6C6F6A",
"$@ c #888A87",
"%@ c #A1A2A0",
"&@ c #CDCDCA",
"*@ c #BDBDBA",
"=@ c #B4B5B2",
"-@ c #CBCCC9",
";@ c #C0C1BF",
">@ c #A3A4A2",
",@ c #8B8C8A",
"'@ c #6D706C",
")@ c #666863",
"!@ c #686966",
"~@ c #81817F",
"{@ c #9A9B98",
"]@ c #B8B9B7",
"^@ c #CCCCCA",
"/@ c #C9C9C6",
"(@ c #B4B4B1",
"_@ c #999A97",
":@ c #828380",
"<@ c #696B67",
"[@ c #676964",
"}@ c #636562",
"|@ c #747571",
"1@ c #898A87",
"2@ c #9A9B97",
"3@ c #A9ABA6",
"4@ c #9C9D99",
"5@ c #888885",
"6@ c #747670",
"7@ c #646662",
"8@ c #61645F",
"9@ c #666864",
"0@ c #80827E",
"a@ c #7E7E7B",
"b@ c #70716E",
"c@ c #656663",
"d@ c #60625D",
"e@ c #6B6E68",
"f@ c #646660",
"g@ c #5F615C",
"h@ c #BCBFB8",
"i@ c #CDCFC8",
"j@ c #D0D4CC",
"k@ c #BFC2BB",
"l@ c #E9EAE6",
"m@ c #E7E8E5",
"n@ c #E7E8E4",
"o@ c #DEDEDB",
"p@ c #9FA19D",
"q@ c #CCD0C8",
"r@ c #CFD3CB",
"s@ c #CDD1C9",
"t@ c #D1D5CE",
"u@ c #D7D9D3",
"v@ c #DCDED8",
"w@ c #E0E2DD",
"x@ c #E4E6E2",
"y@ c #E8EAE6",
"z@ c #D7D9D4",
"A@ c #D0D4CD",
"B@ c #DFE1DC",
"C@ c #EBECE9",
"D@ c #F3F3F1",
"E@ c #F8F8F7",
"F@ c #FAFAF9",
"G@ c #FAFAFA",
"H@ c #CACEC6",
"I@ c #CED2CB",
"J@ c #E2E4E0",
"K@ c #F1F2F0",
"L@ c #F9F9F8",
"M@ c #F9F9F9",
"N@ c #C9CDC5",
"O@ c #CACDC6",
"P@ c #F0F0EF",
"Q@ c #F8F8F8",
"R@ c #F0F1EF",
"S@ c #CBCEC7",
"T@ c #C7CBC4",
"U@ c #C8CCC5",
"V@ c #DEE0DC",
"W@ c #F4F4F3",
"X@ c #DFE0DD",
"Y@ c #C6CAC2",
"Z@ c #C7CBC3",
"`@ c #DCDED9",
" # c #F2F2F1",
".# c #F7F7F6",
"+# c #C5C8C1",
"@# c #D0D3CE",
"## c #EEEFED",
"$# c #F6F6F5",
"%# c #C3C7BF",
"&# c #C5C9C1",
"*# c #F4F4F4",
"=# c #C2C5BE",
"-# c #CACDC7",
";# c #ECEDEB",
"># c #F3F3F2",
",# c #C0C4BD",
"'# c #CED2CD",
")# c #EFEFEE",
"!# c #D4D5D3",
"~# c #ADAEAC",
"{# c #9C9E9B",
"]# c #8C8E8B",
"^# c #6C6D6A",
"/# c #D5D6D2",
"(# c #F0F0EE",
"_# c #F0F0F0",
":# c #EEEEEE",
"<# c #C8C8C7",
"[# c #989997",
"}# c #575955",
"|# c #BDC1BA",
"1# c #DBDDD9",
"2# c #C8C8C6",
"3# c #626460",
"4# c #595B57",
"5# c #BCC0B8",
"6# c #EEEEED",
"7# c #D1D2D0",
"8# c #838481",
"9# c #5B5D59",
"0# c #7E807C",
"a# c #868377",
"b# c #77746B",
"c# c #68665F",
"d# c #5E5E59",
"e# c #BABEB7",
"f# c #D4D6D2",
"g# c #ECECEB",
"h# c #D9DAD8",
"i# c #5D5F5B",
"j# c #959694",
"k# c #AFB1AE",
"l# c #BABAB7",
"m# c #C1C2C0",
"n# c #C5C6C4",
"o# c #747773",
"p# c #757368",
"q# c #C7B89D",
"r# c #C9B99E",
"s# c #C7B69B",
"t# c #C2B198",
"u# c #B8AE97",
"v# c #A19988",
"w# c #7A776A",
"x# c #D3D5D2",
"y# c #B9BDB5",
"z# c #CBCFC9",
"A# c #EAEBE9",
"B# c #E7E8E6",
"C# c #9E9F9C",
"D# c #5F615D",
"E# c #7A7C79",
"F# c #9E9F9B",
"G# c #A6A8A4",
"H# c #AAACA9",
"I# c #C9CAC8",
"J# c #CACBC9",
"K# c #CCBBA0",
"L# c #D0BEA2",
"M# c #CFBDA3",
"N# c #CEBDA1",
"O# c #CDBDA1",
"P# c #A49F91",
"Q# c #B3A996",
"R# c #C1B29A",
"S# c #A6A08F",
"T# c #7C7C78",
"U# c #CBCEC8",
"V# c #B8BBB4",
"W# c #C5C6C1",
"X# c #E8E8E6",
"Y# c #E9E9E8",
"Z# c #DEDEDD",
"`# c #828480",
" $ c #61635F",
".$ c #7C7E7B",
"+$ c #B3B3B2",
"@$ c #C6C6C3",
"#$ c #C7C8C6",
"$$ c #CACAC9",
"%$ c #AEAFAC",
"&$ c #989A96",
"*$ c #D1D1CE",
"=$ c #D6D7D5",
"-$ c #D9D9D7",
";$ c #DBDBD8",
">$ c #CECECB",
",$ c #9C9D9A",
"'$ c #DED3C1",
")$ c #DFD2BD",
"!$ c #DBCEB9",
"~$ c #D9CAB4",
"{$ c #D5C5AA",
"]$ c #8D8E88",
"^$ c #BFB19B",
"/$ c #CDBCA1",
"($ c #CABBA1",
"_$ c #BBB09F",
":$ c #828079",
"<$ c #E7E7E6",
"[$ c #C4C6C0",
"}$ c #B6BAB3",
"|$ c #BABEB8",
"1$ c #D0D0CF",
"2$ c #747672",
"3$ c #636661",
"4$ c #767873",
"5$ c #999997",
"6$ c #ADAEAB",
"7$ c #C8C9C7",
"8$ c #CBCBCA",
"9$ c #CFCFCC",
"0$ c #BFC0BD",
"a$ c #E5E5E2",
"b$ c #E7E2D7",
"c$ c #E8E2D8",
"d$ c #E2DED4",
"e$ c #DED2BF",
"f$ c #D9CAB3",
"g$ c #D3C2A6",
"h$ c #D1BFA3",
"i$ c #CEBDA2",
"j$ c #A99F89",
"k$ c #A99D8B",
"l$ c #7E7B71",
"m$ c #B9BDB7",
"n$ c #B5B8B1",
"o$ c #E5E5E4",
"p$ c #6B6E69",
"q$ c #656863",
"r$ c #696C67",
"s$ c #8D8F8C",
"t$ c #555854",
"u$ c #6B6D6A",
"v$ c #CDCDCB",
"w$ c #E2E2E0",
"x$ c #E7E7E4",
"y$ c #DFE0DE",
"z$ c #E8E8E7",
"A$ c #DFDFDD",
"B$ c #E8E2D7",
"C$ c #EAE3D8",
"D$ c #E9E3D8",
"E$ c #DBD8D1",
"F$ c #D4D3CE",
"G$ c #E8E1D6",
"H$ c #E4DDD0",
"I$ c #DDD0BB",
"J$ c #CCBEA3",
"K$ c #61615B",
"L$ c #595A57",
"M$ c #A59A86",
"N$ c #AAA495",
"O$ c #B3B7B0",
"P$ c #E3E3E2",
"Q$ c #676A65",
"R$ c #72756F",
"S$ c #B5B7B3",
"T$ c #C6C7C5",
"U$ c #5C5E5A",
"V$ c #868885",
"W$ c #CECECD",
"X$ c #E6E6E4",
"Y$ c #E9E9E6",
"Z$ c #DFDFDC",
"`$ c #E9E2D5",
" % c #EBE3D6",
".% c #EAE3D6",
"+% c #E2DDD2",
"@% c #E1DCD2",
"#% c #E8E1D5",
"$% c #E7E1D4",
"%% c #C7C4BD",
"&% c #888985",
"*% c #63655F",
"=% c #C8B79E",
"-% c #BDB49F",
";% c #73766F",
">% c #CACCC7",
",% c #B2B5AE",
"'% c #E1E2E0",
")% c #C2C4C1",
"!% c #7F827D",
"~% c #CBCCCA",
"{% c #D3D3D1",
"]% c #E4E4E1",
"^% c #E8E8E5",
"/% c #EAEAE7",
"(% c #EBEBE8",
"_% c #E0E0DD",
":% c #B8B8B5",
"<% c #ECE5D7",
"[% c #ECE5D6",
"}% c #EBE4D6",
"|% c #EAE2D6",
"1% c #E9E2D6",
"2% c #E0DBD0",
"3% c #B7B8B5",
"4% c #CAC6BD",
"5% c #D9C9B1",
"6% c #D2C0A4",
"7% c #CEBEA2",
"8% c #C6B9A0",
"9% c #83847B",
"0% c #B8BAB4",
"a% c #B0B4AD",
"b% c #C8CAC7",
"c% c #90938E",
"d% c #C4C4C1",
"e% c #B7B7B4",
"f% c #E8E9E7",
"g% c #E9EAE7",
"h% c #EAEAE8",
"i% c #EBEBE9",
"j% c #DADAD8",
"k% c #E0DACF",
"l% c #EAE2D5",
"m% c #ECE4D6",
"n% c #EBE3D5",
"o% c #EAE3D5",
"p% c #C2C1BB",
"q% c #BBBBB7",
"r% c #E6DFD2",
"s% c #E5DED1",
"t% c #DED1BC",
"u% c #D3C2A5",
"v% c #C8B9A0",
"w% c #989588",
"x% c #AFB2AC",
"y% c #B2B5AF",
"z% c #D3D3D2",
"A% c #DDDDDC",
"B% c #D7D7D6",
"C% c #7F827E",
"D% c #6D706B",
"E% c #8B8D8A",
"F% c #A1A3A0",
"G% c #DDDDDB",
"H% c #E3E4E2",
"I% c #E5E5E3",
"J% c #E6E6E5",
"K% c #CECFCD",
"L% c #E1E1E0",
"M% c #ECECE9",
"N% c #E3E3E0",
"O% c #D4D4D1",
"P% c #DFD9CC",
"Q% c #E3DDD1",
"R% c #EEE5D6",
"S% c #D8D3C7",
"T% c #EBE2D3",
"U% c #EDE4D5",
"V% c #DAD4C9",
"W% c #E9E1D3",
"X% c #E8E0D2",
"Y% c #E6DED1",
"Z% c #E0D7C6",
"`% c #A09C8E",
" & c #AFA694",
".& c #938F85",
"+& c #AEB1AA",
"@& c #BFC0BC",
"#& c #DBDCDA",
"$& c #DADBD9",
"%& c #8F928D",
"&& c #6F726D",
"*& c #80827D",
"=& c #8F918C",
"-& c #C6C7C3",
";& c #EDEDEA",
">& c #EEEEEB",
",& c #E9E1D1",
"'& c #EFE6D5",
")& c #C5C2B9",
"!& c #EFE5D5",
"~& c #EAE2D3",
"{& c #F0E6D6",
"]& c #EFE5D6",
"^& c #EEE5D5",
"/& c #DAD4C8",
"(& c #B5B5B1",
"_& c #C1BFB8",
":& c #EBE3D3",
"<& c #EAE2D2",
"[& c #E7DFD0",
"}& c #C1BFB6",
"|& c #95948B",
"1& c #CABAA1",
"2& c #C9B99F",
"3& c #83837C",
"4& c #ACAFA9",
"5& c #D9D9D8",
"6& c #B0B1AE",
"7& c #71746F",
"8& c #777A75",
"9& c #BDBDBB",
"0& c #EDEDEB",
"a& c #EDE3D3",
"b& c #EEE4D4",
"c& c #EAE1D2",
"d& c #E9E1D2",
"e& c #F0E6D5",
"f& c #E6DED0",
"g& c #EDE3D4",
"h& c #ECE3D4",
"i& c #E9E0D2",
"j& c #CDCBC5",
"k& c #C7C6C2",
"l& c #DBD1C0",
"m& c #D5C2A7",
"n& c #C5B8A1",
"o& c #787B75",
"p& c #ABAEA7",
"q& c #D3D4D1",
"r& c #7D807B",
"s& c #737671",
"t& c #747772",
"u& c #B4B6B3",
"v& c #D3D3D0",
"w& c #DCDDDB",
"x& c #E9DFCF",
"y& c #F0E5D4",
"z& c #E1D9CB",
"A& c #EFE5D4",
"B& c #EFE4D4",
"C& c #EBE2D2",
"D& c #E9E0D1",
"E& c #D2CFC6",
"F& c #E4DCCE",
"G& c #E6DDCF",
"H& c #DED2BD",
"I& c #D4C3A6",
"J& c #BBB2A1",
"K& c #A9ADA6",
"L& c #ACB0AA",
"M& c #757873",
"N& c #9EA09C",
"O& c #EBEBEA",
"P& c #EBEBEB",
"Q& c #EDEDEC",
"R& c #D2D3D1",
"S& c #D6D7D7",
"T& c #E4DBCC",
"U& c #F0E5D3",
"V& c #D1CABF",
"W& c #ECE2D1",
"X& c #EFE4D3",
"Y& c #EEE4D3",
"Z& c #EDE3D2",
"`& c #EBE1D1",
" * c #EAE0D0",
".* c #E9DFD0",
"+* c #E7DECF",
"@* c #E5DCCD",
"#* c #DAC9AF",
"$* c #A5A093",
"%* c #A8ABA4",
"&* c #B4B5B1",
"** c #D2D2D1",
"=* c #7C7E7A",
"-* c #7C7F7A",
";* c #878784",
">* c #8A8C88",
",* c #DEDEDC",
"'* c #E3E4E0",
")* c #ECECE8",
"!* c #EFEFEC",
"~* c #DFD6C7",
"{* c #F1E5D2",
"]* c #E7DECD",
"^* c #E5DCCC",
"/* c #F0E5D2",
"(* c #F0E5D1",
"_* c #EEE3D1",
":* c #EDE2D1",
"<* c #EBE0D0",
"[* c #E8DECE",
"}* c #E6DDCD",
"|* c #E2D8C6",
"1* c #C8B89E",
"2* c #837D70",
"3* c #9E9584",
"4* c #7D7F7A",
"5* c #A6AAA3",
"6* c #BABCB8",
"7* c #C1C2BF",
"8* c #CFD0CE",
"9* c #575A56",
"0* c #80827F",
"a* c #C9CAC9",
"b* c #D8D0C1",
"c* c #F0E4D2",
"d* c #EFE4D1",
"e* c #EDE2D0",
"f* c #EBE1CF",
"g* c #EAE0CE",
"h* c #E6DCCC",
"i* c #C4C0B6",
"j* c #585B57",
"k* c #636460",
"l* c #A4A4A2",
"m* c #C7C8C5",
"n* c #A5A8A2",
"o* c #A7AAA4",
"p* c #C6C6C4",
"q* c #7B7E79",
"r* c #848782",
"s* c #919390",
"t* c #5C5F5A",
"u* c #949693",
"v* c #A0A09E",
"w* c #ADAFAB",
"x* c #D6D6D4",
"y* c #B9B9B7",
"z* c #B5B7B6",
"A* c #BFBCB3",
"B* c #F0E4D1",
"C* c #EFE3D0",
"D* c #BAB6AE",
"E* c #BCB8AF",
"F* c #EEE3D0",
"G* c #ECE1CF",
"H* c #D1CABE",
"I* c #A8A8A3",
"J* c #969794",
"K* c #656662",
"L* c #A3A7A0",
"M* c #ADAFAA",
"N* c #BFBFBD",
"O* c #C9C9C7",
"P* c #B6B6B3",
"Q* c #CECFCC",
"R* c #BFC1C0",
"S* c #CEC6B9",
"T* c #F0E3CF",
"U* c #F0E4D0",
"V* c #EEE2CF",
"W* c #C3BDB2",
"X* c #999A98",
"Y* c #D2D2D0",
"Z* c #AFB0AD",
"`* c #A2A59F",
" = c #959793",
".= c #80837F",
"+= c #ABABA8",
"@= c #DCDCDA",
"#= c #B9BAB9",
"$= c #C8C1B4",
"%= c #F0E3CE",
"&= c #E4DAC9",
"*= c #E1D8C7",
"== c #F1E4CF",
"-= c #D2CBBC",
";= c #BAB9B3",
">= c #9A9D99",
",= c #B5B6B2",
"'= c #A1A49D",
")= c #A2A59E",
"!= c #C5C5C3",
"~= c #C2C2C0",
"{= c #838680",
"]= c #81847E",
"^= c #999B95",
"/= c #E4E4E2",
"(= c #D3D4D3",
"_= c #DBD2C1",
":= c #BCB7AD",
"<= c #DED5C4",
"[= c #D5CCBD",
"}= c #AAA8A3",
"|= c #ECECEC",
"1= c #D7D7D4",
"2= c #9FA29C",
"3= c #C1C1BF",
"4= c #C2C2C1",
"5= c #D4D4D2",
"6= c #F0E3CD",
"7= c #E9DDC8",
"8= c #C3BCAF",
"9= c #D8CEBD",
"0= c #9D9D98",
"a= c #B1B1AE",
"b= c #B2B3AF",
"c= c #9EA19B",
"d= c #9A9D98",
"e= c #858882",
"f= c #F1E3CC",
"g= c #E8DBC6",
"h= c #DFD4C1",
"i= c #E8DBC7",
"j= c #E2D7C5",
"k= c #DCD1BE",
"l= c #9F9D96",
"m= c #929390",
"n= c #D9D9D6",
"o= c #EFEFEB",
"p= c #9C9F99",
"q= c #B6B7B4",
"r= c #8D908A",
"s= c #878A84",
"t= c #979993",
"u= c #ACADA9",
"v= c #9B9C98",
"w= c #949691",
"x= c #E3D6C2",
"y= c #EFE1CB",
"z= c #ECDEC8",
"A= c #ABA79E",
"B= c #F0E2CB",
"C= c #EEE0CA",
"D= c #F1E2CB",
"E= c #DFD3C0",
"F= c #A19E96",
"G= c #7B7F7E",
"H= c #B8B9B6",
"I= c #969893",
"J= c #9FA19C",
"K= c #C3C3C2",
"L= c #9B9E98",
"M= c #AAACA8",
"N= c #8A8D87",
"O= c #898C86",
"P= c #A6A8A5",
"Q= c #D8D8D7",
"R= c #EFEFED",
"S= c #D7CCBA",
"T= c #DBD2C0",
"U= c #EFE0C9",
"V= c #D9CEBB",
"W= c #EDDEC7",
"X= c #F1E2CA",
"Y= c #E2D5C0",
"Z= c #A4A097",
"`= c #747877",
" - c #949795",
".- c #D8D8D6",
"+- c #999D96",
"@- c #8B8E88",
"#- c #AEB0AC",
"$- c #DBDBD9",
"%- c #E2E2E2",
"&- c #E4D8C2",
"*- c #EEDFC9",
"=- c #F0E1CA",
"-- c #E4D6C2",
";- c #A5A298",
">- c #727576",
",- c #787A7B",
"'- c #BFC0C0",
")- c #989B95",
"!- c #ABADA9",
"~- c #B5B7B2",
"{- c #DCDCD9",
"]- c #E2E3E2",
"^- c #F0E0C8",
"/- c #E7D9C1",
"(- c #A9A498",
"_- c #6F7372",
":- c #6A6E6F",
"<- c #999C9B",
"[- c #979A93",
"}- c #8F928C",
"|- c #D5D6D4",
"1- c #E6E7E4",
"2- c #AFB1B0",
"3- c #ADA79B",
"4- c #ACA699",
"5- c #686C6D",
"6- c #787C7B",
"7- c #DADBD8",
"8- c #BDBFBB",
"9- c #959892",
"0- c #91948E",
"a- c #A8A8A5",
"b- c #979895",
"c- c #9F9F9D",
"d- c #DDDDDA",
"e- c #7A7D7E",
"f- c #9C9F9E",
"g- c #919393",
"h- c #646869",
"i- c #656A6A",
"j- c #A1A3A3",
"k- c #BCBCBA",
"l- c #A4A5A2",
"m- c #B3B3B0",
"n- c #949791",
"o- c #969993",
"p- c #ACACAA",
"q- c #939690",
"r- c #8B8D89",
"s- c #585B56",
"t- c #5A5C58",
"u- c #72736F",
"v- c #80817F",
"w- c #A3A6A5",
"x- c #787B7C",
"y- c #EAEBE8",
"z- c #626667",
"A- c #D1D2CF",
"B- c #81837F",
"C- c #737371",
"D- c #9FA19E",
"E- c #92958F",
"F- c #949593",
"G- c #6C6E6A",
"H- c #6E716C",
"I- c #727370",
"J- c #7B7D78",
"K- c #D1D1CF",
"L- c #B7B9B7",
"M- c #6F7373",
"N- c #5E6263",
"O- c #616666",
"P- c #ADAFAE",
"Q- c #9EA09F",
"R- c #7D8081",
"S- c #C3C4C2",
"T- c #92938F",
"U- c #7B7D79",
"V- c #A6A6A4",
"W- c #A2A4A0",
"X- c #979A94",
"Y- c #D6D6D5",
"Z- c #BBBCBC",
"`- c #6F7375",
" ; c #5A5E60",
".; c #5A5F61",
"+; c #797D7E",
"@; c #878A8A",
"#; c #9A9D9D",
"$; c #DEDFDD",
"%; c #A3A4A1",
"&; c #727676",
"*; c #575C5D",
"=; c #626666",
"-; c #B4B6B4",
";; c #8E918B",
">; c #9FA09D",
",; c #B7B8B3",
"'; c #ABACAC",
"); c #535859",
"!; c #868A8A",
"~; c #8D8F8A",
"{; c #9DA09A",
"]; c #898C8C",
"^; c #505555",
"/; c #616566",
"(; c #BFC0BE",
"_; c #B4B7B1",
":; c #979995",
"<; c #A2A3A0",
"[; c #C8C8C4",
"}; c #B9B9B5",
"|; c #A6A7A3",
"1; c #E1E1DE",
"2; c #BABBBB",
"3; c #E5E6E5",
"4; c #AEB0AB",
"5; c #949591",
"6; c #A1A49E",
"7; c #A3A6A0",
"8; c #A4A6A2",
"9; c #888A85",
"0; c #949692",
"a; c #C3C3C0",
"b; c #898B86",
"c; c #B1B2AE",
"d; c #888B85",
"e; c #B4B7B3",
"f; c #969793",
"g; c #A4A8A1",
"h; c #A7ABA4",
"i; c #A9ADA7",
"j; c #ABACA9",
"k; c #898B88",
"l; c #7E7F7C",
"m; c #BCBEBB",
"n; c #848781",
"o; c #A0A39E",
"p; c #BFC2BE",
"q; c #BABAB8",
"r; c #727471",
"s; c #595C58",
"t; c #595B58",
"u; c #7F817F",
"v; c #CACAC8",
"w; c #828580",
"x; c #858883",
"y; c #989996",
"z; c #ABAFA8",
"A; c #818280",
"B; c #595C57",
"C; c #5A5C57",
"D; c #5B5D58",
"E; c #D0D0CE",
"F; c #7F807B",
"G; c #5D5E5A",
"H; c #B2B6B0",
"I; c #929490",
"J; c #A6A9A3",
"K; c #ADB1AA",
"L; c #5A5D59",
"M; c #585A56",
"N; c #767874",
"O; c #B7B8B6",
"P; c #6D6F6A",
"Q; c #626461",
"R; c #AFB3AC",
"S; c #6F706C",
"T; c #A7A8A6",
"U; c #858784",
"V; c #B3B7B1",
"W; c #7E817B",
"X; c #82857F",
"Y; c #A5A8A3",
"Z; c #B1B5AE",
"`; c #B3B5B1",
" > c #C5C6C3",
".> c #91928F",
"+> c #B2B6AF",
"@> c #B4B8B2",
"#> c #C5C7C4",
"$> c #81847F",
"%> c #8F918D",
"&> c #A3A6A1",
"*> c #B5B9B2",
"=> c #BABDB6",
"-> c #A3A5A0",
";> c #7A7C77",
">> c #8E8F8C",
",> c #B7BBB4",
"'> c #BEC1BB",
")> c #959691",
"!> c #DCDCDB",
"~> c #949592",
"{> c #A0A19F",
"]> c #787B76",
"^> c #8C8D8A",
"/> c #B9BDB6",
"(> c #C3C4BF",
"_> c #5A5B58",
":> c #595B56",
"<> c #5E5F5C",
"[> c #E1E2DF",
"}> c #8E908B",
"|> c #C4C6C1",
"1> c #777974",
"2> c #989A95",
"3> c #BBBFB8",
"4> c #BCBDB8",
"5> c #C4C5C3",
"6> c #727470",
"7> c #797B78",
"8> c #676965",
"9> c #888986",
"0> c #C2C3BF",
"a> c #797B76",
"b> c #C3C6C1",
"c> c #A4A6A3",
"d> c #D4D4D3",
"e> c #898A89",
"f> c #AFAFAD",
"g> c #C5C7C3",
"h> c #878985",
"i> c #BFC3BC",
"j> c #C2C6C0",
"k> c #8A8B88",
"l> c #DBDCD8",
"m> c #757673",
"n> c #737470",
"o> c #CCCDCA",
"p> c #C3C6C0",
"q> c #747671",
"r> c #868784",
"s> c #C1C5BE",
"t> c #C4C7C1",
"u> c #585A55",
"v> c #BEBEBD",
"w> c #C4C4C2",
"x> c #AFB0AC",
"y> c #CBCBC8",
"z> c #848582",
"A> c #C2C6BF",
"B> c #BEC0B9",
"C> c #848581",
"D> c #C1C1BE",
"E> c #5A5C59",
"F> c #8F928E",
"G> c #70726D",
"H> c #757772",
"I> c #91948F",
"J> c #BFC3BB",
"K> c #C9CBC6",
"L> c #81827F",
"M> c #898B87",
"N> c #B8BCB5",
"O> c #C8CBC4",
"P> c #CCCCC9",
"Q> c #BABAB6",
"R> c #C8CBC3",
"S> c #787976",
"T> c #7F807D",
"U> c #999B97",
"V> c #C0C3BC",
"W> c #CACDC5",
"X> c #C4C7C2",
"Y> c #B5B5B2",
"Z> c #CCCDCB",
"`> c #C1C4BE",
" , c #7D7F7B",
"., c #7F817D",
"+, c #CBCFC7",
"@, c #CBCFC8",
"#, c #CBCEC9",
"$, c #C9CBC5",
"%, c #CDCEC8",
"&, c #CCCFC9",
"*, c #6A6C68",
"=, c #777875",
"-, c #C4C8C0",
";, c #696B66",
">, c #6D6F6B",
",, c #787A76",
"', c #848682",
"), c #ACB0A9",
"!, c #C8CCC4",
"~, c #D1D5CD",
"{, c #6A6C67",
"], c #767773",
"^, c #646762",
"/, c #666964",
"(, c #757773",
"_, c #636561",
":, c #737571",
"<, c #626560",
"[, c #71726F",
"}, c #60625E",
"|, c #5E615C",
"1, c #60635E",
"2, c #686A66",
"3, c #6E706C",
"4, c #666764",
"5, c #6B6C69",
"6, c #6D6E6B",
"7, c #656763",
"8, c #515351",
"9, c #515451",
"0, c #4E504E",
"a, c #545653",
"b, c #4A4D4B",
"c, c #515350",
"d, c #525551",
"e, c #545652",
"f, c #555753",
"g, c #565854",
"h, c #4B4D4C",
"i, c #4B4E4C",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                        . + @ # $ % & *                                                                                                                         ",
"                                                                                                                    = - ; > > > > > , ' ) !                                                                                                                     ",
"                                                                                                                ~ { ] ^ / ( _ : < [ } | 1 2 3 4                                                                                                                 ",
"                                                                                                            5 6 7 8 9 0 a b c d e f g h i j k l m n                                                                                                             ",
"                                                                                                          0 o p $ i q r s t u v v w x y r z A B C D E                                                                                                           ",
"                                                                                                        F G - H I J K                     L M N H - D O                                                                                                         ",
"                                                                                                        P Q R S T w                         U V W X } Y                                                                                                         ",
"                                                                                                      Z `  ...+.                                @.#.n ( $.                                                                                                      ",
"                                                                                                    %.&.G *.=.-.                                ;.>.,.'.).!.                                                                                                    ",
"                                                                                                    a < i ~.{.                                    ].^./.(._.                                                                                                    ",
"                                                                                                    :.<.#.[.                                        }.|.1.2.                                                                                                    ",
"                                                                                                  3.4.5.6.7.                                        8.9.0.a.b.                                                                                                  ",
"                                                                                                  c.4./.d.e.                f.g.7                   h.i.j.k.l.                                                                                                  ",
"                                                                                                  m.n.o.l.          p.q.r.s.$ t.u.v.w.x.y.z.          A.B.C.D.                                                                                                  ",
"                                                                                                  E.F.G.H.          I.J.K.~.L.M.N.O.P.Q.R.S.          T.U.V.W.                                                                                                  ",
"                                                                                                  X.Y.%.Z.          `.J. +~..+M.N.++P.@+#+$+          %+&+U.*+                                                                                                  ",
"                                                                                                  =+-+;+$+          `.J. +~..+M.N.++P.@+#+$+          D.>+a }.                                                                                                  ",
"                                                                                                  ,+'+U.)+          `.J. +~..+M.N.++P.@+#+$+          !+;+~+{+                                                                                                  ",
"                                                                                                  ]+)+^+/+(+        `.J. +~..+M.N.++P.@+#+$+        D._+2.:+<+                                                                                                  ",
"                                                                                                  [+}+h ;+|+        `.J. +~..+M.N.++P.@+#+$+        1+C.2+3+u                                                                                                   ",
"                                                                                                    h.i.4+5+        `.J. +~..+M.N.++P.@+#+$+        ~+6+7+8+                                                                                                    ",
"                                                                                                    9+0+'+V.a+      `.J. +~..+M.N.++P.@+#+$+      b+c+d+e+f+                                                                                                    ",
"                                                                                                    g+h+i+4+j+k+    l+m+n+;+o+p+q+r+s+_+t+u+    k+v+w+x+y+z+                                                                                                    ",
"                                                                                                      A+8+%+B+V.C+    D+E+F+G+H+I+J+a.$+      K+C.L+M+N+O+                                                                                                      ",
"                                                                                                        P+Q+%+R+S+%+    T+U+V+V+V+W+X+Y+    Z+`+ @.@+@@@                                                                                                        ",
"                                                                                                          #@$@%@E &@*@D.T+U+V+V+V+W+X+Y+@+=@-@;@>@,@'@                                                                                                          ",
"                                                                                                          )@!@~@{@]@^@$.T+U+V+V+V+W+X+Y+/@^@(@_@:@<@[@                                                                                                          ",
"                                                                                                              }@|@1@2@3@T+U+V+V+V+W+X+Y+_+4@5@6@7@                                                                                                              ",
"                                                                                                                8@9@x 0@T+U+V+V+V+W+X+Y+a@b@c@8@                                                                                                                ",
"                                                                                                                    d@e@T+U+V+V+V+W+X+Y+f@g@                                                                                                                    ",
"                                                                                                                        T+U+V+V+V+W+X+Y+                                                                                                                        ",
"                                                                                                                  R.R.h@T+U+V+V+V+W+X+Y+i@R.R.                                                                                                                  ",
"                                                                                                        j@j@j@j@j@j@j@k@%+Y l@m@n@o@F.p@q@j@j@j@j@j@j@j@                                                                                                        ",
"                                                                                                  r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@                                                                                                  ",
"                                                                                            s@s@s@s@s@s@s@s@s@s@s@s@t@u@v@w@x@y@y@x@w@v@z@R.s@s@s@s@s@s@s@s@s@s@s@s@                                                                                            ",
"                                                                                          q@q@q@q@q@q@q@q@A@B@C@D@E@F@G@G@G@G@G@G@G@G@G@G@F@E@D@C@B@A@q@q@q@q@q@q@q@q@                                                                                          ",
"                                                                                      H@H@H@H@H@H@H@I@J@K@L@M@M@M@M@M@M@M@M@M@M@M@M@M@M@M@M@M@M@M@M@L@K@J@r@H@H@H@H@H@H@H@                                                                                      ",
"                                                                                  N@N@N@N@N@N@O@w@P@Q@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@L@Q@R@w@S@N@N@N@N@N@N@                                                                                  ",
"                                                                              T@T@T@T@T@T@U@V@W@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@E@W@X@U@T@T@T@T@T@T@                                                                              ",
"                                                                            Y@Y@Y@Y@Y@Z@`@ #.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.# #`@Z@Y@Y@Y@Y@Y@                                                                            ",
"                                                                          +#+#+#+#+#@###$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$#$###@#+#+#+#+#+#                                                                          ",
"                                                                        %#%#%#%#&#J@W@*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#W@J@&#%#%#%#%#                                                                        ",
"                                                                    =#=#=#=#=#-#;#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#>#;#-#=#=#=#=#=#                                                                    ",
"                                                                  ,#,#,#,#,#'#)# # # # # # # # # # # # # # # # # #!#>+~#{#]#U ^#^#U ]#{#~#>+!# # # # # # # # # # # # # # # # # #)#'#,#,#,#,#,#                                                                  ",
"                                                                k@k@k@k@k@/#(#_#_#_#_#_#_#_#_#_#_#_#_#_#_#:#<#[#L.}#}#}#}#}#}#}#}#}#}#}#}#}#}#L.[#<#:#_#_#_#_#_#_#_#_#_#_#_#_#_#_#(#/#k@k@k@k@k@                                                                ",
"                                                              |#|#|#|#|#1#)#)#)#)#)#)#)#)#)#)#)#)#)#)#2#e.3#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#3#e.2#)#)#)#)#)#)#)#)#)#)#)#)#)#)#1#|#|#|#|#|#                                                              ",
"                                                              5#5#5#5#/ 6#6#6#6#6#6#6#6#6#6#6#6#6#7#8#9#9#9#9#9#9#9#9#9#9#3#b@0#a#b#c#d#9#9#9#9#9#9#9#9#9#8#7#6#6#6#6#6#6#6#6#6#6#6#6#6#/ 5#5#5#5#                                                              ",
"                                                            e#e#e#e#f#g#g#g#g#g#g#g#g#g#g#g#g#h#e..+i#i#i#i#i#i#z+j#k#l#m#n#d+o#p#q#r#s#t#u#v#w#i#i#i#i#i#i#.+e.h#g#g#g#g#g#g#g#g#g#g#g#g#x#e#e#e#e#                                                            ",
"                                                          y#y#y#y#z#A#A#A#A#A#A#A#A#A#A#A#B#C#3#D#D#D#D#D#E#F#l#G#H#I#J#<.^@x.}#}#K#L#M#N#O#P#Q#R#S#T#D#D#D#D#D#3#C#B#A#A#A#A#A#A#A#A#A#A#A#U#y#y#y#y#                                                          ",
"                                                        V#V#V#V#W#X#Y#Y#Y#Y#Y#Y#Y#Y#Y#Y#Z#`# $ $ $ $ $.$+$@$#$$$%$&$*$=$-$;$>$,$,$'$)$!$~${$]$^$M#/$($_$:$ $ $ $ $ $`#Z#Y#Y#Y#Y#Y#Y#Y#Y#Y#Y#<$[$V#V#V#V#                                                        ",
"                                                      }$}$}$}$|$l <$<$<$<$<$<$<$<$<$<$1$2$3$3$3$3$4$5$6$7$8$9$!#9 0$a$, > > | 0$0$b$c$c$c$d$F.e$f$g$h$i$j$k$l$3$3$3$3$2$1$<$<$<$<$<$<$<$<$<$<$l m$}$}$}$}$                                                      ",
"                                                      n$n$n$n$h#o$o$o$o$o$o$o$o$o$o$>+p$q$q$q$r$T+s$t$u$v$h#w$; x$4 y$X#z$I+A$j+j+B$C$C$D$E$F$B$G$H$I$J$K$L$M$N$r$q$q$q$p$>+o$o$o$o$o$o$o$o$o$o$-$n$n$n$n$                                                      ",
"                                                    O$O$O$O$).P$P$P$P$P$P$P$P$P$P$/+Q$Q$Q$Q$R$S$T$_+U$V$W$o$X$> X#- P$z$Y$Y$Z$l#l#`$ %.%.%+%@%`$`$#%$%%%&%*%=%O#-%;%Q$Q$Q$Q$/+P$P$P$P$P$P$P$P$P$P$>%O$O$O$O$                                                    ",
"                                                    ,%,%,%V#y$'%'%'%'%'%'%'%'%'%)%p$r$r$r$!%%.#$~%{%Z h 2.]%^%Y$Y$/%/%(%(%(%_%:%:% %<%<%<%[%}%.%|%1%2%a 3%4%5%6%7%8%9%r$r$r$p$)%'%'%'%'%'%'%'%'%'%t.0%,%,%,%                                                    ",
"                                                  a%a%a%a%b%W+W+W+W+W+W+W+W+W+~ 2$p$p$p$c%d%7$&@$ 7 W+e%=@J#X#f%g%h%g.i%i%> h%j%k%l% %m%m%m% %n%o%l%p%=@q%r%s%t%u%L#v%w%p$p$p$2$~ W+W+W+W+W+W+W+W+W+b%a%a%a%a%                                                  ",
"                                                  x%x%x%y%z%A%A%A%A%A%A%A%A%B%C%D%D%D%E%F%%+&@G%H%I%J%K%/+~.L%g.i%i%M%N%/ ^%^ O%P%Q%R%S%T%R%R%U%U%V%/+/+V%W%X%Y%Z%g$`% &.&D%D%D%C%B%A%A%A%A%A%A%A%A%z%y%x%x%x%                                                  ",
"                                                +&+&+&+&@&9 #&#&#&#&#&#&#&$&%&&&&&&&*&B+X+=&-&1 a$] > x$h a o@M%M%;&x$(%@&i%>&- ,&'&,&)&!&~&{&]&^&/&(&_&:&T%<&X%[&}&|&1&2&3&&&&&&&%&$&#&#&#&#&#&#&#&9 @&+&+&+&+&                                                ",
"                                                4&4&4&z 2#= 5&5&5&5&5&5&5&6&7&7&7&8&9&7$&@6 `+G > X#I+g.7 g.H+0&0&V+7 M%> V+6#8 a&{&b&c&d&d&e&{&!&^&c&f&g&h&<&i&j&k&l&m&L#n&o&7&7&7&6&5&5&5&5&5&5&5&= 2#z 4&4&4&                                                ",
"                                              p&p&p&p&%.O q&v.v.v.v.v.v.{%r&s&s&t&u&T$^@J+'%G%v&X$X#I+h%i%H+H+V+i%0.I%V+V+V+V+w&x&y&y&y&y&z&)&y&y&y&A&B&b&a&C&D&E&F&G&H&I&M#J&t&s&s&r&{%v.v.v.v.v.v.q&O %.p&p&p&p&                                              ",
"                                              K&K&K&L&`+`+K%!#!#!#!#!#!#G#M&M&M&N&n#8$q&8 P$X$<$z$g.O&P&Q&Q&6#6#6#X$R&6#6#6#6#S&T&y&U&U&U&V&W&U&U&U&U&X&Y&Z&Z&`& *.*+*@*#*u%i$$*M&M&M&G#!#!#!#!#!#!#K%`+`+L&K&K&K&                                              ",
"                                              %*%*%*&*R+R+<.**********<.=*8&8&-*;*>*/@,*'*] x$Y$/%)*;&>&>&!*!*!*_%^%!*!*!*!*!*G ~*{*{*{*{*{*]*^*{*{*{*{*/*(*_*:*<*x&[*}*|*1*2*3*4*8&8&=*<.**********<.R+R+&*%*%*%*                                              ",
"                                            5*5*5*5*6*7*7*T$8*8*8*8*8*N&[+[+[+Y+9*}#0*U+1 X$X#h%i%H+0&V+V+V+V+V+V+V+V+V+V+V+V+a*b*/*/*/*/*/*/*/*/*/*/*/*/*c*d*_*e*f*g*h*i*4*j*k*l*[+[+[+N&8*8*8*8*8*m*7*7*6*5*5*5*5*                                            ",
"                                            n*n*n*o*0$0$0$0.v$v$v$v$p*r&q*q*r*S+s*t*u*v*w*x*I+h%C@0&0&V+V+V+V+<$y*0$V+V+V+V+V+z*A*B*B*B*B*C*D*E*B*B*B*B*B*B*B*C*F*G*H*I*p@J*K*%@#$r*q*q*r&p*v$v$v$v$R+0$0$0$o*n*n*n*                                            ",
"                                            L*L*L*M*Z Z Z N*$$$$$$$$K+r&r&r&%$T$&@O*P*C#O.O.Q*(%H+0&V+V+V+V+V+V+V+V+V+V+V+V+V+R*S*T*T*U*U*U*U*U*U*U*U*U*U*U*U*C*V*W*X*q+a+N*O%Y*&@Z*r&r&r&K+$$$$$$$$N*Z Z Z M*L*L*L*                                            ",
"                                          `*`*`*`*&*V.V.V.V.`+2#2#2# =!%!%.=)%$$4 #&w$9 +=T.] i%H+0&0&0&0&0&0&0&@=X$0&0&0&0&0&#=$=%=%=%=%=%=&=*=%=%=%=%=%=%=====-=;=>=,=G%I%Z#!#4  @.=!%!% =2#2#2#`+V.V.V.V.&*`*`*`*`*                                          ",
"                                          '='='=)=r+4+4+4+4+X+!=!=~={=]=]=^=T$^@Y*_%/=I%> A$i%g#V+V+V+V+V+6#6#6#6#!#B+6#6#6#6#(=_=T*T*T*T*:=<=T*T*T*T*T*T*T*[=}=*$|=W+Y#z$o$7 1=Y*^@0+]=]={=~=!=!=X+4+4+4+4+r+)='='='=                                          ",
"                                          2=2=2=G#y*y*y*y*y*y*3=4=%${={={=6&7$9$5=L%P$J%f%h%g#0&6#6#6#6#6#6#6#6#Y#m#O&6#6#6#6#6#6=6=6=6=6=7=8=6=6=6=6=6=9=0=a=h%V+;&H+h%Y$X$/=-$5=9$b={={={=%$4=3=y*y*y*y*y*y*G#2=2=2=                                          ",
"                                          c=c=c=l.3%3%3%3%3%3%4+0$d=e=e=e=g q+6&O*' I%X#I+i%0&V+!*!*!*!*!*!*!*!*!*!*j%(%v.H+!*!*f=f=g=h=i=j=f=f=f=f=k=l=m=n=o=o=o=>&;&)*Y$^%^ >%'+0+Z*e=e=e=d=0$U.3%3%3%3%3%3%l.c=c=c=                                          ",
"                                          p=p=p=3@d+d+d+d+d+d+q=U.r=s=s=t=4+u=v=w=S+a$X#/%M%0&V+V+V+V+V+V+V+V+V+V+V+i%x$.@>&H+` x=y=z=A=B=C=D=D=E=F=G=H=0&V+V+V+V+V+0&M%h%X#-+I=J=b=K=t=s=s=r=U.q=d+d+d+d+d+d+3@p=p=p=                                          ",
"                                          L=L=L=M==@=@=@=@=@=@=@d+N=O=O=P=T$>${%Q=G%X$I+i%0&V+R=R=R=R=R=R=R=R=R=R=R=R=]%| 1 8 p*S=T=U=V=W=X=Y=Z=`= -,*V+V+V+V+V+V+V+0&H+h%X#A%| .-{%>$1+O=O=N=d+=@=@=@=@=@=@=@M=L=L=L=                                          ",
"                                          +-+-+-!+/+/+/+/+/+/+/+%$@-@-@-#-7$9$5=$-%-; z$g.g#V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+h%V+@=&-*-U==---;->-,-'->&>&>&>&>&>&>&>&>&>&H+h%X#2 Z#-$5=9$k#@-@-@-%$/+/+/+/+/+/+/+!++-+-+-                                          ",
"                                        )-)-)-)-!-6&6&6&6&6&6&6&.@r=r=r=~-I#4 !#{-]-X$X#g.O&Q&Q&Q&0&0&0&0&0&0&0&0&0&0&0&0&0&0&0&^-^-/-(-_-:-<-k 0&0&0&0&0&0&0&0&0&0&0&i%i%I+> y$J+!#4 -+r=r=r=.@6&6&6&6&6&6&6&!-)-)-)-)-                                        ",
"                                        [-[-[-[-6$Z*Z*Z*Z*Z*Z*Z*k+}-}-}-4+J#~ |-Q 7 1-X#i%;&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+#&2-3-4-_-5-6-b%V+V+V+V+V+V+V+V+V+V+V+V+V+;&i%Y$1-t.7-|-~ 8-}-}-}-k+Z*Z*Z*Z*Z*Z*Z*6$[-[-[-[-                                        ",
"                                        9-9-9-9-6$6$6$6$6$6$6$6$T.0-0-0-a-b-[.c-%@3%4+d-(%H+>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&Y$e-f-g-h-i-j-X#>&>&V+V+V+V+V+V+V+V+V+V+V+V+g#=$k-r+l-%@c-[.m-0-0-0-T.6$6$6$6$6$6$6$6$9-9-9-9-                                        ",
"                                        n-n-n-o-p-p-p-p-p-p-p-p-p@q-q-q-r-}#s-4#t-u-v--@i%0&Q&V+V+V+V+V+V+V+V+V+V+V+V+V+(%w-x-V+y-z-A-V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+!*>&;+B-C-t-t-4#s-D-q-q-q-p@p-p-p-p-p-p-p-p-o-n-n-n-                                        ",
"                                        E-E-E-q-M+M+M+M+M+M+M+M+*+9-9-9-F-G-H-z+I-J-s*K-O&Q&6#6#6#6#6#6#6#6#6#6#6#6#;&L-M-N-O-P-Q-R-;&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+0&S-T-U-9+I-z+H-V-9-9-9-*+M+M+M+M+M+M+M+M+q-E-E-E-                                        ",
"                                        0-0-0-0-%+:+:+:+:+:+:+:+W-X-X-X-&+$$A-Y-$-A$] z$i%g#V+V+V+V+V+V+V+V+V+V+Q&Z-`- ;.;.;+;@;#;$;V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+g#i%X#/=A$$-Y-A-3=X-X-X-W-:+:+:+:+:+:+:+%+0-0-0-0-                                        ",
"                                        }-}-}-}-%;Z.Z.Z.Z.Z.Z.Z.l-=+=+=+M.J#~ |-$-A$^ X#M%;&!*!*!*!*!*!*!*!*!*R*&;*;*;*;=;-;!*!*!*!*!*!*!*!*!*V+V+V+V+V+V+V+V+V+V+V+V+g#i%> 1 A$$-|-~ V.=+=+=+l-Z.Z.Z.Z.Z.Z.Z.%;}-}-}-}-                                        ",
"                                          ;;;;;;>;x+x+x+x+x+x+x+l-L=L=L=,;I#4 !#7-$;7 > g.0&6#Q&Q&Q&Q&Q&Q&Q&';););););!;y$Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&H+h%] 7 $;7-!#4 -+L=L=L=l-x+x+x+x+x+x+x+>;;;;;;;                                          ",
"                                          ~;~;~;q+%;%;%;%;%;%;%;%;{;{;{;9.7$9$5=J+Z#w$o$/%H+>&>&>&>&>&>&>&>&>&];^;/;(;>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&>&H+I+o$w$Z#J+5=9$_;{;{;{;%;%;%;%;%;%;%;%;q+~;~;~;                                          ",
"                                          @-@-@-:;<;<;<;<;<;<;<;<;2=2=2=w*#$[;};|;'+1;I%z$O&0&V+V+V+V+V+V+V+V+2;g-3;V+V+V+V+V+V+V+V+V+V+V+R=R=R=R=R=R=R=R=R=R=R=R=R=V+i%X#I%|;H#0$K%>$4;2=2=2=<;<;<;<;<;<;<;<;:;@-@-@-                                          ",
"                                          8+8+8+5;a+a+a+a+a+a+a+a+*+6;6;7;8;9;0;m.-&X@/=X$g.H+Q&Q&Q&Q&Q&Q&Q&Q&z$Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&Q&H+h%> /=a;)+{+b;c;7;6;6;*+a+a+a+a+a+a+a+a+5;8+8+8+                                          ",
"                                          d;d;d;}-C#C#C#C#C#C#C#C#i+7;7;7;,;S-~ x*7-$;7 X$g%O&0&0&0&0&0&0&0&0&0&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+R=O&g%X$7 $;7-x*p*B.7;7;7;i+C#C#C#C#C#C#C#C#}-d;d;d;                                          ",
"                                          s=s=s=O=O.O.O.O.O.O.O.O.C#n*n*n*_.I#9$5=n=A%1;I%X#i%0&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+R=0&i%X#I%1;A%n=5=9$e;n*n*n*C#O.O.O.O.O.O.O.O.O=s=s=s=                                          ",
"                                          e=e=e=e=f;q+q+q+q+q+q+q+q+g;h;h;i; @&@Y*( @=,*j;k;I+H+V+R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=R=V+V+V+X#l;m;1 _%@=( Y*~%i;h;h;g;q+q+q+q+q+q+q+q+f;e=e=e=e=                                          ",
"                                            n;n;n;N+_@_@_@_@_@_@_@_@o;K&K&K&p;J#~ !#q;r;s;t;V.i%H+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+Q&V+H+<;4#t;u;v;J+!#~ *.K&K&K&o;_@_@_@_@_@_@_@_@N+n;n;n;                                            ",
"                                            w;w;w;x;y;y;y;y;y;y;y;y;q+z;z;z;y%5.0$A;B;C;D;N+n=I+H+0&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+>&>&>&>&>&>&>&>&>&>&0&>&0&V+0&H+E;F;s;t-G;{+8$v$H;z;z;z;q+y;y;y;y;y;y;y;y;x;w;w;w;                                            ",
"                                            ]=]=]=]=I;J*J*J*J*J*J*J*J*J;K;K;K;c.L;M;4#N;a;8 I%> h%O&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+O&h%> I%O;P;C;4#Q;>+K;K;K;J;J*J*J*J*J*J*J*J*I;]=]=]=]=                                            ",
"                                              !%!%!%>*0;0;0;0;0;0;0;0;}.R;R;R;H;S;c@T;1=$-$;w$o$> y-i%V+V+V+V+V+V+0&0&0&0&0&0&0&0&0&0&0&0&0&0&V+V+V+V+V+V+V+i%y-> o$w$$;B%F#D#U;V;R;R;R;}.0;0;0;0;0;0;0;0;>*!%!%!%                                              ",
"                                              W;W;W;X;o+o+o+o+o+o+o+o+o+Y;Z;Z;Z;`;O  .5=` d-Z$7 o$X#y-i%V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+i%y-X#o$7 Z$d-` 5= >2.Z;Z;Z;Y;o+o+o+o+o+o+o+o+o+X;W;W;W;                                              ",
"                                              4*4*4*4*N+.>.>.>.>.>.>.>.>7.+>O$O$@>#>^@A-!#-$#&v&]%o$X#(%O&0&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+0&O&(%X#o$9 X@w&-$!#A-I#@>O$O$+>7..>.>.>.>.>.>.>.>N+4*4*4*4*                                              ",
"                                                q*q*q*$>%>%>%>%>%>%>%>%>%>&>*>*>*>=>2#&@Y*= ->[.C 7 I%m@I+i%H+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+H+i%I+m@I%W+T-'+J+x*Y*v$I.*>*>*>&>%>%>%>%>%>%>%>%>%>$>q*q*q*                                                ",
"                                                ;>;>;>;>1@>>>>>>>>>>>>>>>>,+Z;,>,>,>'>7$&@i+)>Y*!>_%7 I%>>%@X$H+0&V+V+V+V+V+V+V+V+V+V+V+V+V+V+V+0&1;~>{>X$I%7 _%v$=&c.**>$k@,>,>,>Z;,+>>>>>>>>>>>>>>>>1@;>;>;>;>                                                ",
"                                                  ]>]>]>-*^>^>^>^>^>^>^>^>^>o+}$/>/>/>(>%;++<.Y-J+/ A$(;_>4#!.I+h%H+i%H+0&0&V+V+V+V+V+0&0&H+i%H+h%>;:><>z%[>A$/ J+2#}>'+|>/>/>/>}$o+^>^>^>^>^>^>^>^>^>-*]>]>]>                                                  ",
"                                                  1>1>1>1>]+>*>*>*>*>*>*>*>*>*2>e#3>3>3>4>5>9$Y*|--$$-6>_>7>2 o$^%Y$I+h%i%H+O&H+i%H+O&H+i%h%I+Y$^%,*8>t-9>,*@=-$|-Y*n.0>3>3>3>e#2>>*>*>*>*>*>*>*>*>*]+1>1>1>1>                                                  ",
"                                                    4$4$4$a>1@1@1@1@1@1@1@1@1@1@i+|#|#|#|#b>v;>$Y*!#c>s;9#K=8 7 I%I%] > X#Y$d>e>k;X$I+Y$X#> ] I%I%7 f>_>t-V.+ !#Y*n g>|#|#|#|#i+1@1@1@1@1@1@1@1@1@1@a>4$4$4$                                                    ",
"                                                    t&t&t&t&!%h>h>h>h>h>h>h>h>h>h>i;i>i>i>i>j>U+&@5.k*4#k>$-!>Z#W+l>7 /=I%o$ @4#4#w$o$o$I%7 o@[>W+Z#@=m>_>n>v&~ o>p>i>i>i>i>i;h>h>h>h>h>h>h>h>h>h>!%t&t&t&t&                                                    ",
"                                                      9+9+9+q>8#r>r>r>r>r>r>r>r>r>r>E.s>s>s>s>t><#,@u>.+5.1=-$$-d-v=v>X@8 p w>_>_>Z#w$p 8 x>l.Z#d-$--$;+t-j*l*y>t>s>s>s>s>E.r>r>r>r>r>r>r>r>r>r>8#q>9+9+9+                                                      ",
"                                                      7&7&7&7&t&8#z>z>z>z>z>z>z>z>z>z>e+=#%#%#%#A>B>C>J* .Y*5=Y-G b;~ @=w&!>D>E>t-$-A%!>w&a;T--$+ Y-5=Y*&%F>[$A>%#%#%#=#e+z>z>z>z>z>z>z>z>z>z>8#t&7&7&7&7&                                                      ",
"                                                        G>G>G>G>H>`#`#`#`#`#`#`#`#`#`#`#I>J>&#&#&#&#&#K>y>&@9$A-q;I;x*1=+ -$*@C;C;x*n=-$+ v&b;/@{%A-9$o>A &#&#&#&#&#J>I>`#`#`#`#`#`#`#`#`#`#`#H>G>G>G>G>                                                        ",
"                                                          H-H-H-H-N;L>L>L>L>L>L>L>L>L>L>L>M>N>Z@Z@Z@Z@Z@O>A ).P>g W.~ Y*Y*{%Q>4#4#K-5={%Y*Y*0+c;>$(.).R>Z@Z@Z@Z@Z@N>M>L>L>L>L>L>L>L>L>L>L>L>N;H-H-H-H-                                                          ",
"                                                            P;P;P;P;S>T>T>T>T>T>T>T>T>T>T>T>T>U>V>N@N@N@N@N@N@W>X>n.J#^@&@>$Y>u>u>P>9$>$&@Z>`>F W>N@N@N@N@N@N@V>U>T>T>T>T>T>T>T>T>T>T>T>T>S>P;P;P;P;                                                            ",
"                                                            p$p$p$p$p$u  , , , , , , , , , , , ,.,2=&#+,+,+,+,+,+,+,+,q@@,#,$,|.|.%,&,@,q@+,+,+,+,+,+,+,+,&#2=., , , , , , , , , , , , ,u p$p$p$p$p$                                                            ",
"                                                              *,*,*,*,s =,U U U U U U U U U U U U U 0@D.-,s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@s@-,D.0@U U U U U U U U U U U U U =,s *,*,*,*,                                                              ",
"                                                                ;,;,;,;,;,6>T T T T T T T T T T T T T T T r-J;,#r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@r@,#J;r-T T T T T T T T T T T T T T T 6>;,;,;,;,;,                                                                ",
"                                                                  8>8>8>8>8>>,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,',2=),*>k@!,j@~,~,j@!,k@*>),2=',,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,>,8>8>8>8>8>                                                                  ",
"                                                                    )@)@)@)@)@{,],=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,S>0@0@S>=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,=,],{,)@)@)@)@)@                                                                    ",
"                                                                      ^,^,^,^,^,/,6>(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,(,6>/,^,^,^,^,^,                                                                      ",
"                                                                        3#_,_,_,_,_,*,6>:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,:,6>*,_,_,_,_,_,3#                                                                        ",
"                                                                            8@8@8@8@8@<,<@[,I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-I-[,<@<,8@8@8@8@8@                                                                            ",
"                                                                              },},},},},}, $<@z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+z+<@ $},},},},},},                                                                              ",
"                                                                                L;|,|,|,|,|,|,1,2,>,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,>,2,1,|,|,|,|,|,|,L;                                                                                ",
"                                                                                    _>i#i#i#i#i#i#i# $4,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,4, $i#i#i#i#i#i#i#s;                                                                                    ",
"                                                                                        t;U$U$U$U$U$U$U$U$D#_,2,s s s s s s s s s s s s s s s s 2,_,D#U$U$U$U$U$U$U$U$t;                                                                                        ",
"                                                                                            M;t-t-t-t-t-t-t-t-t-t-9#i#.+}, $_,7,7,_, $},.+i#9#t-t-t-t-t-t-t-t-t-t-M;                                                                                            ",
"                                                                                                8,}#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#4#}#9,                                                                                                ",
"                                                                                                      0,a,}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#}#a,0,                                                                                                      ",
"                                                                                                            b,c,d,e,f,g,g,g,g,g,g,g,g,g,g,f,e,d,c,h,                                                                                                            ",
"                                                                                                                              i,i,                                                                                                                              ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                "};

static const char * tplay_xpm[] = {
"48 48 524 2",
"   c None",
".  c #DCDCDA",
"+  c #E2E2DF",
"@  c #E0E1DE",
"#  c #D9DAD5",
"$  c #CFD1CB",
"%  c #DADBD8",
"&  c #B9BAB5",
"*  c #969994",
"=  c #939691",
"-  c #B4B6B2",
";  c #DCDDDA",
">  c #D3D5D0",
",  c #C4C6C3",
"'  c #CFD1CD",
")  c #878984",
"!  c #888A86",
"~  c #D2D3CF",
"{  c #C9CBC8",
"]  c #CFD0CC",
"^  c #91938E",
"/  c #939490",
"(  c #D0D1CD",
"_  c #C4C5C1",
":  c #C4C5C2",
"<  c #A8ABA7",
"[  c #B5B8B3",
"}  c #B6B9B4",
"|  c #BBBCB8",
"1  c #B3B4B1",
"2  c #B7BAB5",
"3  c #B4B7B2",
"4  c #A8AAA5",
"5  c #959692",
"6  c #B8B9B6",
"7  c #979C97",
"8  c #B5B7B2",
"9  c #A5A6A2",
"0  c #A1A29E",
"a  c #BEC1BB",
"b  c #BCBDB9",
"c  c #949592",
"d  c #C5C5C1",
"e  c #C1C1BE",
"f  c #969793",
"g  c #B7B8B5",
"h  c #BBBCBA",
"i  c #B5B5B2",
"j  c #B7B9B4",
"k  c #979996",
"l  c #A1A3A1",
"m  c #BFC0BD",
"n  c #949792",
"o  c #EEEEEC",
"p  c #E6E6E4",
"q  c #8F918B",
"r  c #BFC0BE",
"s  c #A6A7A5",
"t  c #81827E",
"u  c #A0A39F",
"v  c #A0A19D",
"w  c #81827F",
"x  c #888B86",
"y  c #82837E",
"z  c #CFD2CA",
"A  c #CFD3CB",
"B  c #BEC1BA",
"C  c #DDDFDA",
"D  c #D9DBD5",
"E  c #BEC2BB",
"F  c #CBCFC8",
"G  c #D7DAD3",
"H  c #E7E9E5",
"I  c #EEF0EE",
"J  c #F3F4F2",
"K  c #F7F7F6",
"L  c #C8CCC4",
"M  c #CACDC6",
"N  c #DEE0DC",
"O  c #F1F1F1",
"P  c #F8F8F7",
"Q  c #C4C8C0",
"R  c #D3D5D1",
"S  c #F0F1EF",
"T  c #F5F5F4",
"U  c #C0C3BD",
"V  c #C0C4BC",
"W  c #DADCD8",
"X  c #F1F1F0",
"Y  c #F2F2F1",
"Z  c #EDEDEC",
"`  c #D2D2D0",
" . c #B1B2B1",
".. c #929391",
"+. c #BCC0B9",
"@. c #DEDFDC",
"#. c #EEEEED",
"$. c #D2D3D1",
"%. c #7E807D",
"&. c #5E605C",
"*. c #5B5D59",
"=. c #656763",
"-. c #7C7E7B",
";. c #858175",
">. c #6B6A61",
",. c #5C5D58",
"'. c #B8BCB5",
"). c #D2D3D0",
"!. c #EAEAE9",
"~. c #E8E8E6",
"{. c #A5A6A4",
"]. c #636561",
"^. c #80817C",
"/. c #ABABA8",
"(. c #A9ABA8",
"_. c #CACBC9",
":. c #AEA699",
"<. c #CFBFA7",
"[. c #B0A692",
"}. c #B4A993",
"|. c #898477",
"1. c #B4B8B1",
"2. c #C4C6C1",
"3. c #E4E5E3",
"4. c #E5E5E4",
"5. c #D3D3D1",
"6. c #7F817D",
"7. c #6A6C68",
"8. c #8D8E8C",
"9. c #9C9E9C",
"0. c #D9DAD8",
"a. c #D6D3CB",
"b. c #E8E2D7",
"c. c #DBD7CE",
"d. c #E1D7C6",
"e. c #9D9588",
"f. c #9D937F",
"g. c #6D6D67",
"h. c #B1B4AE",
"i. c #DBDBD9",
"j. c #E0E0DF",
"k. c #DEDEDC",
"l. c #80827D",
"m. c #838580",
"n. c #BEBFBD",
"o. c #D4D5D3",
"p. c #BBBBB8",
"q. c #E1E2DF",
"r. c #DBDBDA",
"s. c #DFD9CF",
"t. c #EAE3D5",
"u. c #EAE3D6",
"v. c #E2DBD0",
"w. c #BDBCB6",
"x. c #DDD1BE",
"y. c #C9B89F",
"z. c #8B887C",
"A. c #ADB0A9",
"B. c #BBBDB8",
"C. c #DADAD8",
"D. c #A2A3A0",
"E. c #767974",
"F. c #B9B9B6",
"G. c #C7C7C4",
"H. c #E4E4E2",
"I. c #D7D7D5",
"J. c #E1E1DF",
"K. c #E9E9E7",
"L. c #ECE3D4",
"M. c #E3DBCE",
"N. c #EDE4D5",
"O. c #E1DACC",
"P. c #DCD5CB",
"Q. c #E8E0D2",
"R. c #C9C4BA",
"S. c #C6B89F",
"T. c #7A7B73",
"U. c #A9ACA6",
"V. c #C2C3C0",
"W. c #D4D4D2",
"X. c #C0C0BE",
"Y. c #777974",
"Z. c #A0A19E",
"`. c #D5D5D3",
" + c #E7E7E5",
".+ c #EBEBE9",
"++ c #ECECEB",
"@+ c #E0E0DD",
"#+ c #EDEDEB",
"$+ c #E5E5E3",
"%+ c #EBE1D0",
"&+ c #EEE4D2",
"*+ c #E2D9CB",
"=+ c #F0E5D4",
"-+ c #EEE4D4",
";+ c #ECE2D3",
">+ c #E8DED0",
",+ c #DFD1BC",
"'+ c #ADA28C",
")+ c #A5A8A2",
"!+ c #ACAEA9",
"~+ c #CBCBCA",
"{+ c #CECECC",
"]+ c #8A8D88",
"^+ c #969892",
"/+ c #7B7C78",
"(+ c #B5B6B4",
"_+ c #DFDFDD",
":+ c #EAEAE8",
"<+ c #ECECEA",
"[+ c #E0E0DE",
"}+ c #E3D8C7",
"|+ c #F0E4D1",
"1+ c #E1D7C7",
"2+ c #EFE4D0",
"3+ c #E3D9C9",
"4+ c #B4B3AC",
"5+ c #868782",
"6+ c #989A95",
"7+ c #A1A59E",
"8+ c #B0B2AE",
"9+ c #BBBCB9",
"0+ c #C1C2BF",
"a+ c #C0C1BF",
"b+ c #80837E",
"c+ c #B9BAB8",
"d+ c #D4D4D1",
"e+ c #CDCECA",
"f+ c #DDDEDB",
"g+ c #DDDDDB",
"h+ c #E0E1DF",
"i+ c #E5D9C7",
"j+ c #EEE1CC",
"k+ c #E0D6C4",
"l+ c #F0E3CE",
"m+ c #DBD2C3",
"n+ c #CFCCC5",
"o+ c #9EA19A",
"p+ c #B2B2AF",
"q+ c #B7B7B5",
"r+ c #B8B8B6",
"s+ c #AFAFAD",
"t+ c #868883",
"u+ c #AAABA7",
"v+ c #CBCBC8",
"w+ c #E5E6E4",
"x+ c #DFDFDE",
"y+ c #EBEBEA",
"z+ c #EEE1CB",
"A+ c #DFD4C2",
"B+ c #EDDFCB",
"C+ c #D7CDBC",
"D+ c #BFBCB5",
"E+ c #E3E2E0",
"F+ c #EFEFEC",
"G+ c #D0D1CF",
"H+ c #B4B5B2",
"I+ c #9A9D97",
"J+ c #B0B1AD",
"K+ c #B2B3B0",
"L+ c #A0A29D",
"M+ c #C9CAC8",
"N+ c #DCDCDB",
"O+ c #EEEEEB",
"P+ c #E2E2E0",
"Q+ c #E8DBC4",
"R+ c #D6CBB8",
"S+ c #A4A29B",
"T+ c #C6C6C3",
"U+ c #D8D8D6",
"V+ c #979995",
"W+ c #969993",
"X+ c #AEAFAB",
"Y+ c #AEAFAC",
"Z+ c #999B96",
"`+ c #A1A49E",
" @ c #ABACA9",
".@ c #BEBFBB",
"+@ c #B9BBB9",
"@@ c #8F8E89",
"#@ c #9D9E9C",
"$@ c #E6E6E5",
"%@ c #E6EDDF",
"&@ c #C9EAA9",
"*@ c #CBE9AD",
"=@ c #D1E5BC",
"-@ c #C4C6C0",
";@ c #B6B7B3",
">@ c #A5A6A1",
",@ c #92958F",
"'@ c #AAAAA8",
")@ c #9B9E97",
"!@ c #9E9F9C",
"~@ c #8B8C88",
"{@ c #999A96",
"]@ c #DBDCD9",
"^@ c #959797",
"/@ c #7D8080",
"(@ c #AAACAC",
"_@ c #CFE8B5",
":@ c #BEE697",
"<@ c #B8DF92",
"[@ c #A2BB89",
"}@ c #8E918B",
"|@ c #A3A4A1",
"1@ c #A5A6A3",
"2@ c #A6A8A2",
"3@ c #CDCDCA",
"4@ c #B6B9B8",
"5@ c #5A5F61",
"6@ c #9EA1A1",
"7@ c #E9E9E8",
"8@ c #ABDF79",
"9@ c #B6E28B",
"0@ c #B2DB88",
"a@ c #A4BC8B",
"b@ c #8A8D87",
"c@ c #9D9E9A",
"d@ c #A1A29F",
"e@ c #A2A59F",
"f@ c #ADAEAA",
"g@ c #C1C2C0",
"h@ c #ECECE9",
"i@ c #DDDEDC",
"j@ c #D1D2D1",
"k@ c #93D851",
"l@ c #ABDE79",
"m@ c #B1E280",
"n@ c #B4E681",
"o@ c #B2E480",
"p@ c #AFE17F",
"q@ c #AEDF7D",
"r@ c #A8D67C",
"s@ c #A2B390",
"t@ c #949692",
"u@ c #9C9D9A",
"v@ c #9D9F9B",
"w@ c #A6A9A2",
"x@ c #C3C3C0",
"y@ c #D5D6D4",
"z@ c #D4D5D2",
"A@ c #8BD342",
"B@ c #9AD75D",
"C@ c #AAE274",
"D@ c #ACE475",
"E@ c #AAE173",
"F@ c #A6DC70",
"G@ c #A5DA70",
"H@ c #A5DA71",
"I@ c #9CC277",
"J@ c #888E83",
"K@ c #898C87",
"L@ c #989996",
"M@ c #BABAB6",
"N@ c #969895",
"O@ c #6D706B",
"P@ c #C9C9C8",
"Q@ c #EFEFED",
"R@ c #80CD37",
"S@ c #81CD36",
"T@ c #A4E168",
"U@ c #A5E369",
"V@ c #A1DD66",
"W@ c #9BD663",
"X@ c #9BD563",
"Y@ c #99CF63",
"Z@ c #80837D",
"`@ c #939591",
" # c #9EA09C",
".# c #B0B4AD",
"+# c #959693",
"@# c #D0D0CE",
"## c #77C72A",
"$# c #72C622",
"%# c #91DD46",
"&# c #9DE05B",
"*# c #9BDE5A",
"=# c #94D456",
"-# c #91D055",
";# c #90D053",
"># c #7B7E78",
",# c #878884",
"'# c #8F908D",
")# c #AAACA6",
"!# c #BABCB5",
"~# c #D7D8D4",
"{# c #E4E5E1",
"]# c #6FC11F",
"^# c #80DA29",
"/# c #92DE48",
"(# c #95DF4C",
"_# c #8DD349",
":# c #87CA46",
"<# c #86CB45",
"[# c #777B76",
"}# c #797B77",
"|# c #8A8B88",
"1# c #8B8C89",
"2# c #B7BAB3",
"3# c #B8B9B5",
"4# c #CACAC6",
"5# c #DADAD7",
"6# c #797B78",
"7# c #C9C9C6",
"8# c #BFC3B8",
"9# c #6BBD1C",
"0# c #7EDA25",
"a# c #7FDA27",
"b# c #89DC37",
"c# c #8DDD3F",
"d# c #80C939",
"e# c #7CC437",
"f# c #737671",
"g# c #7C7E7A",
"h# c #868884",
"i# c #BCC1B9",
"j# c #C2C6BF",
"k# c #A8AAA6",
"l# c #CDCECB",
"m# c #A4A6A2",
"n# c #AEAEAC",
"o# c #E6E7E4",
"p# c #D0D1CE",
"q# c #DFE1DC",
"r# c #68B91A",
"s# c #7BD722",
"t# c #7CD822",
"u# c #7FD828",
"v# c #84D930",
"w# c #7ACA2D",
"x# c #71BD29",
"y# c #71BC28",
"z# c #6FBB25",
"A# c #6F726D",
"B# c #7C7D79",
"C# c #828380",
"D# c #898A87",
"E# c #B2B5AF",
"F# c #C3C6BF",
"G# c #C3C5C1",
"H# c #CFD1CE",
"I# c #B5B6B2",
"J# c #9F9F9C",
"K# c #A7A8A6",
"L# c #DCDCD9",
"M# c #B7B8B3",
"N# c #D4D6D3",
"O# c #68B61E",
"P# c #64B517",
"Q# c #78D41F",
"R# c #7AD720",
"S# c #7AD721",
"T# c #7BD721",
"U# c #78D320",
"V# c #6ABF1B",
"W# c #65B518",
"X# c #64B518",
"Y# c #6C6E69",
"Z# c #7A7C78",
"`# c #7E7F7C",
" $ c #9C9E99",
".$ c #C7CBC3",
"+$ c #CBCFC7",
"@$ c #CDD0CA",
"#$ c #CED0CB",
"$$ c #69B224",
"%$ c #60B014",
"&$ c #75D11C",
"*$ c #78D61D",
"=$ c #6EC619",
"-$ c #61B214",
";$ c #5FB014",
">$ c #696A66",
",$ c #696A67",
"'$ c #737572",
")$ c #8C8F8A",
"!$ c #9EA19B",
"~$ c #B0B3AD",
"{$ c #C2C5BE",
"]$ c #62A620",
"^$ c #5DAC11",
"/$ c #70CA18",
"($ c #76D41A",
"_$ c #6EC717",
":$ c #61B313",
"<$ c #5EAC11",
"[$ c #646562",
"}$ c #646662",
"|$ c #6C6E6A",
"1$ c #747572",
"2$ c #757673",
"3$ c #5E9F22",
"4$ c #59A80F",
"5$ c #66BC13",
"6$ c #72D017",
"7$ c #6BC415",
"8$ c #5EB011",
"9$ c #59A70F",
"0$ c #5D605C",
"a$ c #60625E",
"b$ c #616460",
"c$ c #70726E",
"d$ c #5F922E",
"e$ c #56A30C",
"f$ c #57A40C",
"g$ c #55A20C",
"h$ c #595B57",
"i$ c #5C5E5A",
"j$ c #5D5F5B",
"k$ c #626560",
"l$ c #676965",
"m$ c #6A6C69",
"n$ c #5C7A40",
"o$ c #529F09",
"p$ c #529C0C",
"q$ c #525551",
"r$ c #575955",
"s$ c #585B56",
"t$ c #5A5D57",
"u$ c #565F4E",
"v$ c #4F9011",
"w$ c #4C8715",
"x$ c #4B4C4B",
"y$ c #4E4F4D",
"                                                                                                ",
"                                            . + @ #                                             ",
"                                        $ % & * = - ; >                                         ",
"                                      , ' )         ! ~ {                                       ",
"                                      ] ^             / (                                       ",
"                                      _                 :                                       ",
"                                    < [     } | 1 2     3 4                                     ",
"                                    5 6   7 8 9 0 a     b c                                     ",
"                                      d   7 8 9 0 a     e                                       ",
"                                      f g   [ h i j   6 k                                       ",
"                                        l m n o p q r s                                         ",
"                                          t u o p v w                                           ",
"                                            x o p y                                             ",
"                                      z A A B C D E A A z                                       ",
"                                  F F G H I J K K J I H G F F                                   ",
"                              L M N O P P P P P P P P P P O N M L                               ",
"                            Q R S T T T T T T T T T T T T T T S R Q                             ",
"                        U V W X Y Y Y Y Z `  ..... .` Z Y Y Y Y X W V U                         ",
"                        +.@.#.#.#.#.$.%.&.*.=.-.;.>.,.&.%.$.#.#.#.#.@.+.                        ",
"                      '.).!.!.!.~.{.].^./.(._.s :.<.[.}.|.].{.~.!.!.!.).'.                      ",
"                    1.2.3.4.4.5.6.7.8.9.. 0.p 5.a.b.c.d.e.f.g.6.5.4.4.3.2.1.                    ",
"                    h.i.j.j.k.l.m.n.o.p.q.~.~.r.s.t.u.v.w.x.y.z.l.k.j.j.i.h.                    ",
"                  A.B.C.C.C.D.E.F.G.H.I.J.K.J.p L.M.N.O.P.Q.R.S.T.D.C.C.C.B.A.                  ",
"                  U.V.W.W.X.Y.Z.`.q. +.+++@+#+$+%+&+*+=+-+;+>+,+'+Y.X.W.W.V.U.                  ",
"                )+!+X.~+{+]+^+/+(+_+:+#+<+[+o i.}+|+1+|+|+2+3+4+5+6+]+{+~+X.!+)+                ",
"                7+8+9+0+a+b+c+d+e+f+<+#+#+g+#+h+i+j+k+l+l+m+n+d+_+r b+a+0+9+8+7+                ",
"                o+p+q+r+s+t+u+v+w+!.o o o !.x+y+z+A+B+C+D+E+F+.+G+H+t+s+r+q+p+o+                ",
"                I+J+K+K+L+* M+N+p <+O+O+O+O+:+P+Q+R+S+T+F+F+F+#+H.U+V+L+K+K+J+I+                ",
"                W+X+Y+Y+Z+`+ @.@q.#+o o o o o +@@@#@$@#.%@&@*@=@-@;@>@Z+Y+Y+X+W+                ",
"                ,@'@'@'@)@!@~@{@]@o o o o g+^@/@(@#.#.#._@:@:@:@<@[@7+)@'@'@'@,@                ",
"                }@|@1@1@L+2@3@i.p #+Z Z 4@5@6@7@Z Z Z Z 8@9@9@9@9@9@0@a@1@1@|@}@                ",
"                b@c@d@d@0 e@f@g@H.h@o o i@j@o o o o o o k@l@m@n@o@p@q@q@r@s@c@b@                ",
"                ) t@u@u@v@w@x@y@z@J.o o o o o o o o o o A@B@C@D@D@D@E@F@G@H@I@J@                ",
"                m.K@L@L@L@U.M@N@O@P@<+Q@#+O+O+O+F+F+F+o R@S@T@U@U@U@U@U@V@W@X@Y@                ",
"                  Z@`@c c  #.#+#@#[+K.o o o o #+#+o o o ##$#%#&#&#&#&#&#&#*#=#-#-#;#            ",
"                  >#,#'#'#'#)#!#3@;@P+~#~.o o o o o o {#]#]#^#/#(#(#(#(#(#(#(#_#:#:#<#          ",
"                  [#}#|#1#1#'#2#3#4#5#6#7#:+#+$+p o #+8#9#9#0#a#b#c#c#c#c#c#c#c#d#e#e#          ",
"                    f#g#h#h#h#* i#j#k#! N+l#$+m#n#o#p#q#r#r#s#t#t#u#v#v#v#v#v#w#x#y#z#          ",
"                      A#B#C#C#C#D#E#F#G#H#I#5#J#K#L#M#N#O#P#Q#R#R#R#R#S#T#U#V#W#X#P#            ",
"                      Y#Y#Z#`#`#`#`# $.$+$M @$& B.#$M +$$$%$&$*$*$*$*$*$=$-$%$;$                ",
"                        >$,$'$}#}#}#}#g#)$!$~${${$~$!$)$]$^$/$($($($_$:$^$^$<$                  ",
"                          [$}$|$1$2$2$2$2$2$2$2$2$2$2$2$3$4$5$6$7$8$4$4$9$                      ",
"                            0$a$b$7.c$c$c$c$c$c$c$c$c$c$d$e$f$e$e$e$g$                          ",
"                                h$i$j$k$l$m$|$|$|$|$m$l$n$o$o$o$p$                              ",
"                                    q$r$s$s$s$t$t$s$s$s$u$v$w$                                  ",
"                                            x$y$y$x$                                            ",
"                                                                                                ",
"                                                                                                "};

wxIcon ICO_ICON, ICO_TRAY, ICO_ABOUT, ICO_ADD, ICO_GADD, ICO_EDIT, ICO_GEDIT, ICO_DELETE, ICO_GDELETE;
wxIcon ICO_TPLAY, ICO_PLAY, ICO_GPLAY, ICO_PAUSE, ICO_GPAUSE, ICO_ASC, ICO_DESC;

wxIcon makeIcon(const wxString &path, const wxString &name)
{
    if(wxFileExists(path+wxFILE_SEP_PATH+name))
    {
        return wxIcon(path+wxFILE_SEP_PATH+name, wxBITMAP_TYPE_PNG);
    }
    else
    {
        if(name=="dxtime.png")
        {
            wxIcon icon(dxtime_xpm);
            return icon;
        }
        else if(name=="about.png")
        {
            wxIcon icon(about_xpm);
            return icon;
        }
        else if(name=="tplay.png")
        {
            wxIcon icon(tplay_xpm);
            return icon;
        }
        else
        {
            wxIcon icon(empty);
            return icon;
        }
    }
}

wxIcon makeGreyedIcon(const wxString &path, const wxString &name)
{
    if(wxFileExists(path+wxFILE_SEP_PATH+name))
    {
        wxImage img(path+wxFILE_SEP_PATH+name, wxBITMAP_TYPE_PNG);
        wxIcon icon;
        icon.CopyFromBitmap(wxBitmap(img.ConvertToGreyscale()));
        return icon;
    }
    wxImage img(empty);
    wxIcon icon;
    icon.CopyFromBitmap(wxBitmap(img.ConvertToGreyscale()));
    return icon;
}

wxIcon makeScaledIcon(const wxString &path, int max)
{
    if(wxFileExists(path))
    {
        wxImage img(path);
        int w = img.GetWidth();
        int h = img.GetHeight();
        if(w>max || h>max)
        {
            if(w>h)
                img = img.Scale(max, (max*h)/w);
            else
                img = img.Scale((max*w)/h, max);
        }
        wxIcon icon;
        icon.CopyFromBitmap(wxBitmap(img));
        return icon;
    }
    return wxIcon(empty);
}

void makeAllIcons(const wxString &path)
{
    wxString themePath;
    if(path == "default")
    {
#if defined (__WXMAC__)
        themePath = wxStandardPaths::Get().GetResourcesDir()+"/icons";
#else
        themePath = wxString(DXTIME_DATADIR)+wxFILE_SEP_PATH+"icons";
#endif
    }
    else
    {
        themePath = path;
    }
    ICO_ICON = makeIcon(themePath, "dxtime.png");
    ICO_TRAY = makeIcon(themePath, "dxtime.png");
    ICO_ABOUT = makeIcon(themePath, "about.png");
    ICO_ADD = makeIcon(themePath, "add.png");
    ICO_GADD = makeGreyedIcon(themePath, "add.png");
    ICO_EDIT = makeIcon(themePath, "edit.png");
    ICO_GEDIT = makeGreyedIcon(themePath, "edit.png");
    ICO_DELETE = makeIcon(themePath, "delete.png");
    ICO_GDELETE = makeGreyedIcon(themePath, "delete.png");
    ICO_TPLAY = makeIcon(themePath, "tplay.png");
    ICO_PLAY = makeIcon(themePath, "play.png");
    ICO_GPLAY = makeGreyedIcon(themePath, "play.png");
    ICO_PAUSE = makeIcon(themePath, "pause.png");
    ICO_GPAUSE = makeGreyedIcon(themePath, "pause.png");
    ICO_ASC = makeScaledIcon(themePath+wxFILE_SEP_PATH+"asc.png", 16);
    ICO_DESC = makeScaledIcon(themePath+wxFILE_SEP_PATH+"desc.png", 16);
}
