/***************************************************************
 * Name:      settings.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#include <wx/stdpaths.h>
#include <wx/fileconf.h>
#include "settings.h"

Settings::Settings()
{
    wxString iniPath = wxStandardPaths::Get().GetUserDataDir();
    if(!wxDirExists(iniPath))
    {
        wxMkdir(iniPath);
    }
    iniPath << wxFILE_SEP_PATH << "dxtime.ini";
    wxFileConfig *conf = new wxFileConfig("APPNAME", "COMPANYNAME", iniPath);
    wxConfigBase::Set(conf);

    m_x = 50;
    m_y = 50;
    m_w = 888;
    m_h = 666;
    m_maximized = false;
    m_auiperspective = "layout2|name=Navigation;caption=Navigation;state=17404;dir=4;layer=0;row=0;pos=0;prop=100000;bestw=200;besth=100;minw=100;minh=100;maxw=-1;maxh=-1;floatx=-1;floaty=-1;floatw=-1;floath=-1|name=Detail;caption=Detail;state=256;dir=5;layer=0;row=0;pos=0;prop=100000;bestw=20;besth=20;minw=-1;minh=-1;maxw=-1;maxh=-1;floatx=-1;floaty=-1;floatw=-1;floath=-1|dock_size(4,0,0)=202|dock_size(5,0,0)=20|";
    m_showSubtasks = false;

    m_dbname = "dxtime.db";
}

Settings::~Settings()
{}

Settings &Settings::instance()
{
    static Settings s;
    return s;
}

void Settings::load()
{
    wxConfigBase::Get()->Read("GUI/x", &m_x, m_x);
    wxConfigBase::Get()->Read("GUI/y", &m_y, m_y);
    wxConfigBase::Get()->Read("GUI/w", &m_w, m_w);
    wxConfigBase::Get()->Read("GUI/h", &m_h, m_h);
    wxConfigBase::Get()->Read("GUI/maximized", &m_maximized, m_maximized);
    wxConfigBase::Get()->Read("GUI/auiperspective", &m_auiperspective, m_auiperspective);
    wxConfigBase::Get()->Read("GUI/showSubtasks", &m_showSubtasks, m_showSubtasks);
    wxConfigBase::Get()->Read("DB/dbname", &m_dbname, m_dbname);
}

void Settings::save()
{
    wxConfigBase::Get()->Write("GUI/x", m_x);
    wxConfigBase::Get()->Write("GUI/y", m_y);
    wxConfigBase::Get()->Write("GUI/w", m_w);
    wxConfigBase::Get()->Write("GUI/h", m_h);
    wxConfigBase::Get()->Write("GUI/maximized", m_maximized);
    wxConfigBase::Get()->Write("GUI/auiperspective", m_auiperspective);
    wxConfigBase::Get()->Write("GUI/showSubtasks", m_showSubtasks);
    wxConfigBase::Get()->Write("DB/dbname", m_dbname);
    wxConfigBase::Get()->Flush();
}

int Settings::x() const
{
    return m_x;
}

void Settings::setX(int x)
{
    m_x = x;
}

int Settings::y() const
{
    return m_y;
}

void Settings::setY(int y)
{
    m_y = y;
}

int Settings::w() const
{
    return m_w;
}

void Settings::setW(int w)
{
    m_w = w;
}

int Settings::h() const
{
    return m_h;
}

void Settings::setH(int h)
{
    m_h = h;
}

bool Settings::maximized() const
{
    return m_maximized;
}

void Settings::setMaximized(bool maximized)
{
    m_maximized = maximized;
}

wxString Settings::dbname() const
{
    return m_dbname;
}

void Settings::setDbname(const wxString &dbname)
{
    m_dbname = dbname;
}

wxString Settings::auiperspective() const
{
    return m_auiperspective;
}

void Settings::setAuiperspective(const wxString &auiperspective)
{
    m_auiperspective = auiperspective;
}

bool Settings::showSubtasks() const
{
    return m_showSubtasks;
}

void Settings::setShowSubtasks(bool showSubtasks)
{
    m_showSubtasks = showSubtasks;
}
